class DateTimeOffset(object,IComparable,IFormattable,ISerializable,IDeserializationCallback,IComparable[DateTimeOffset],IEquatable[DateTimeOffset]):
 """
 Represents a point in time,typically expressed as a date and time of day,relative to Coordinated Universal Time (UTC).

 

 DateTimeOffset(ticks: Int64,offset: TimeSpan)

 DateTimeOffset(dateTime: DateTime)

 DateTimeOffset(dateTime: DateTime,offset: TimeSpan)

 DateTimeOffset(year: int,month: int,day: int,hour: int,minute: int,second: int,offset: TimeSpan)

 DateTimeOffset(year: int,month: int,day: int,hour: int,minute: int,second: int,millisecond: int,offset: TimeSpan)

 DateTimeOffset(year: int,month: int,day: int,hour: int,minute: int,second: int,millisecond: int,calendar: Calendar,offset: TimeSpan)
 """
 def Add(self,timeSpan):
  """
  Add(self: DateTimeOffset,timeSpan: TimeSpan) -> DateTimeOffset

  

   Adds a specified time interval to a System.DateTimeOffset object.

  

   timeSpan: A System.TimeSpan object that represents a positive or a negative time interval.

   Returns: An object whose value is the sum of the date and time represented by the current 

    System.DateTimeOffset object and the time interval represented by timeSpan.
  """
  pass
 def AddDays(self,days):
  """
  AddDays(self: DateTimeOffset,days: float) -> DateTimeOffset

  

   Adds a specified number of whole and fractional days to the current System.DateTimeOffset object.

  

   days: A number of whole and fractional days. The number can be negative or positive.

   Returns: An object whose value is the sum of the date and time represented by the current 

    System.DateTimeOffset object and the number of days represented by days.
  """
  pass
 def AddHours(self,hours):
  """
  AddHours(self: DateTimeOffset,hours: float) -> DateTimeOffset

  

   Adds a specified number of whole and fractional hours to the current System.DateTimeOffset 

    object.

  

  

   hours: A number of whole and fractional hours. The number can be negative or positive.

   Returns: An object whose value is the sum of the date and time represented by the current 

    System.DateTimeOffset object and the number of hours represented by hours.
  """
  pass
 def AddMilliseconds(self,milliseconds):
  """
  AddMilliseconds(self: DateTimeOffset,milliseconds: float) -> DateTimeOffset

  

   Adds a specified number of milliseconds to the current System.DateTimeOffset object.

  

   milliseconds: A number of whole and fractional milliseconds. The number can be negative or positive.

   Returns: An object whose value is the sum of the date and time represented by the current 

    System.DateTimeOffset object and the number of whole milliseconds represented by milliseconds.
  """
  pass
 def AddMinutes(self,minutes):
  """
  AddMinutes(self: DateTimeOffset,minutes: float) -> DateTimeOffset

  

   Adds a specified number of whole and fractional minutes to the current System.DateTimeOffset 

    object.

  

  

   minutes: A number of whole and fractional minutes. The number can be negative or positive.

   Returns: An object whose value is the sum of the date and time represented by the current 

    System.DateTimeOffset object and the number of minutes represented by minutes.
  """
  pass
 def AddMonths(self,months):
  """
  AddMonths(self: DateTimeOffset,months: int) -> DateTimeOffset

  

   Adds a specified number of months to the current System.DateTimeOffset object.

  

   months: A number of whole months. The number can be negative or positive.

   Returns: An object whose value is the sum of the date and time represented by the current 

    System.DateTimeOffset object and the number of months represented by months.
  """
  pass
 def AddSeconds(self,seconds):
  """
  AddSeconds(self: DateTimeOffset,seconds: float) -> DateTimeOffset

  

   Adds a specified number of whole and fractional seconds to the current System.DateTimeOffset 

    object.

  

  

   seconds: A number of whole and fractional seconds. The number can be negative or positive.

   Returns: An object whose value is the sum of the date and time represented by the current 

    System.DateTimeOffset object and the number of seconds represented by seconds.
  """
  pass
 def AddTicks(self,ticks):
  """
  AddTicks(self: DateTimeOffset,ticks: Int64) -> DateTimeOffset

  

   Adds a specified number of ticks to the current System.DateTimeOffset object.

  

   ticks: A number of 100-nanosecond ticks. The number can be negative or positive.

   Returns: An object whose value is the sum of the date and time represented by the current 

    System.DateTimeOffset object and the number of ticks represented by ticks.
  """
  pass
 def AddYears(self,years):
  """
  AddYears(self: DateTimeOffset,years: int) -> DateTimeOffset

  

   Adds a specified number of years to the System.DateTimeOffset object.

  

   years: A number of years. The number can be negative or positive.

   Returns: An object whose value is the sum of the date and time represented by the current 

    System.DateTimeOffset object and the number of years represented by years.
  """
  pass
 @staticmethod
 def Compare(first,second):
  """
  Compare(first: DateTimeOffset,second: DateTimeOffset) -> int

  

   Compares two System.DateTimeOffset objects and indicates whether the first is earlier than the 

    second,equal to the second,or later than the second.

  

  

   first: The first object to compare.

   second: The second object to compare.

   Returns: A signed integer that indicates whether the value of the first parameter is earlier than,later 

    than,or the same time as the value of the second parameter,as the following table shows.Return 

    valueMeaningLess than zerofirst is earlier than second.Zerofirst is equal to second.Greater than 

    zerofirst is later than second.
  """
  pass
 def CompareTo(self,other):
  """
  CompareTo(self: DateTimeOffset,other: DateTimeOffset) -> int

  

   Compares the current System.DateTimeOffset object to a specified System.DateTimeOffset object 

    and indicates whether the current object is earlier than,the same as,or later than the second 

    System.DateTimeOffset object.

  

  

   other: An object to compare with the current System.DateTimeOffset object.

   Returns: A signed integer that indicates the relationship between the current System.DateTimeOffset 

    object and other,as the following table shows.Return ValueDescriptionLess than zeroThe current 

    System.DateTimeOffset object is earlier than other.ZeroThe current System.DateTimeOffset object 

    is the same as other.Greater than zero.The current System.DateTimeOffset object is later than 

    other.
  """
  pass
 def Equals(self,*__args):
  """
  Equals(first: DateTimeOffset,second: DateTimeOffset) -> bool

  

   Determines whether two specified System.DateTimeOffset objects represent the same point in time.

  

   first: The first object to compare.

   second: The second object to compare.

   Returns: true if the two System.DateTimeOffset objects have the same System.DateTimeOffset.UtcDateTime 

    value; otherwise,false.

  

  Equals(self: DateTimeOffset,other: DateTimeOffset) -> bool

  

   Determines whether the current System.DateTimeOffset object represents the same point in time as 

    a specified System.DateTimeOffset object.

  

  

   other: An object to compare to the current System.DateTimeOffset object.

   Returns: true if both System.DateTimeOffset objects have the same System.DateTimeOffset.UtcDateTime 

    value; otherwise,false.

  

  Equals(self: DateTimeOffset,obj: object) -> bool

  

   Determines whether a System.DateTimeOffset object represents the same point in time as a 

    specified object.

  

  

   obj: The object to compare to the current System.DateTimeOffset object.

   Returns: true if the obj parameter is a System.DateTimeOffset object and represents the same point in 

    time as the current System.DateTimeOffset object; otherwise,false.
  """
  pass
 def EqualsExact(self,other):
  """
  EqualsExact(self: DateTimeOffset,other: DateTimeOffset) -> bool

  

   Determines whether the current System.DateTimeOffset object represents the same time and has the 

    same offset as a specified System.DateTimeOffset object.

  

  

   other: The object to compare to the current System.DateTimeOffset object.

   Returns: true if the current System.DateTimeOffset object and other have the same date and time value and 

    the same System.DateTimeOffset.Offset value; otherwise,false.
  """
  pass
 @staticmethod
 def FromFileTime(fileTime):
  """
  FromFileTime(fileTime: Int64) -> DateTimeOffset

  

   Converts the specified Windows file time to an equivalent local time.

  

   fileTime: A Windows file time,expressed in ticks.

   Returns: An object that represents the date and time of fileTime with the offset set to the local time 

    offset.
  """
  pass
 @staticmethod
 def FromUnixTimeMilliseconds(milliseconds):
  """ FromUnixTimeMilliseconds(milliseconds: Int64) -> DateTimeOffset """
  pass
 @staticmethod
 def FromUnixTimeSeconds(seconds):
  """ FromUnixTimeSeconds(seconds: Int64) -> DateTimeOffset """
  pass
 def GetHashCode(self):
  """
  GetHashCode(self: DateTimeOffset) -> int

  

   Returns the hash code for the current System.DateTimeOffset object.

   Returns: A 32-bit signed integer hash code.
  """
  pass
 @staticmethod
 def Parse(input,formatProvider=None,styles=None):
  """
  Parse(input: str,formatProvider: IFormatProvider,styles: DateTimeStyles) -> DateTimeOffset

  

   Converts the specified string representation of a date and time to its System.DateTimeOffset 

    equivalent using the specified culture-specific format information and formatting style.

  

  

   input: A string that contains a date and time to convert.

   formatProvider: An object that provides culture-specific format information about input.

   styles: A bitwise combination of enumeration values that indicates the permitted format of input. A 

    typical value to specify is System.Globalization.DateTimeStyles.None.

  

   Returns: An object that is equivalent to the date and time that is contained in input as specified by 

    formatProvider and styles.

  

  Parse(input: str,formatProvider: IFormatProvider) -> DateTimeOffset

  

   Converts the specified string representation of a date and time to its System.DateTimeOffset 

    equivalent using the specified culture-specific format information.

  

  

   input: A string that contains a date and time to convert.

   formatProvider: An object that provides culture-specific format information about input.

   Returns: An object that is equivalent to the date and time that is contained in input,as specified by 

    formatProvider.

  

  Parse(input: str) -> DateTimeOffset

  

   Converts the specified string representation of a date,time,and offset to its 

    System.DateTimeOffset equivalent.

  

  

   input: A string that contains a date and time to convert.

   Returns: An object that is equivalent to the date and time that is contained in input.
  """
  pass
 @staticmethod
 def ParseExact(input,*__args):
  """
  ParseExact(input: str,formats: Array[str],formatProvider: IFormatProvider,styles: DateTimeStyles) -> DateTimeOffset

  

   Converts the specified string representation of a date and time to its System.DateTimeOffset 

    equivalent using the specified formats,culture-specific format information,and style. The 

    format of the string representation must match one of the specified formats exactly.

  

  

   input: A string that contains a date and time to convert.

   formats: An array of format specifiers that define the expected formats of input.

   formatProvider: An object that supplies culture-specific formatting information about input.

   styles: A bitwise combination of enumeration values that indicates the permitted format of input.

   Returns: An object that is equivalent to the date and time that is contained in the input parameter,as 

    specified by the formats,formatProvider,and styles parameters.

  

  ParseExact(input: str,format: str,formatProvider: IFormatProvider,styles: DateTimeStyles) -> DateTimeOffset

  

   Converts the specified string representation of a date and time to its System.DateTimeOffset 

    equivalent using the specified format,culture-specific format information,and style. The 

    format of the string representation must match the specified format exactly.

  

  

   input: A string that contains a date and time to convert.

   format: A format specifier that defines the expected format of input.

   formatProvider: An object that supplies culture-specific formatting information about input.

   styles: A bitwise combination of enumeration values that indicates the permitted format of input.

   Returns: An object that is equivalent to the date and time that is contained in the input parameter,as 

    specified by the format,formatProvider,and styles parameters.

  

  ParseExact(input: str,format: str,formatProvider: IFormatProvider) -> DateTimeOffset

  

   Converts the specified string representation of a date and time to its System.DateTimeOffset 

    equivalent using the specified format and culture-specific format information. The format of the 

    string representation must match the specified format exactly.

  

  

   input: A string that contains a date and time to convert.

   format: A format specifier that defines the expected format of input.

   formatProvider: An object that supplies culture-specific formatting information about input.

   Returns: An object that is equivalent to the date and time that is contained in input as specified by 

    format and formatProvider.
  """
  pass
 def Subtract(self,value):
  """
  Subtract(self: DateTimeOffset,value: TimeSpan) -> DateTimeOffset

  

   Subtracts a specified time interval from the current System.DateTimeOffset object.

  

   value: The time interval to subtract.

   Returns: An object that is equal to the date and time represented by the current System.DateTimeOffset 

    object,minus the time interval represented by value.

  

  Subtract(self: DateTimeOffset,value: DateTimeOffset) -> TimeSpan

  

   Subtracts a System.DateTimeOffset value that represents a specific date and time from the 

    current System.DateTimeOffset object.

  

  

   value: An object that represents the value to subtract.

   Returns: An object that specifies the interval between the two System.DateTimeOffset objects.
  """
  pass
 def ToFileTime(self):
  """
  ToFileTime(self: DateTimeOffset) -> Int64

  

   Converts the value of the current System.DateTimeOffset object to a Windows file time.

   Returns: The value of the current System.DateTimeOffset object,expressed as a Windows file time.
  """
  pass
 def ToLocalTime(self):
  """
  ToLocalTime(self: DateTimeOffset) -> DateTimeOffset

  

   Converts the current System.DateTimeOffset object to a System.DateTimeOffset object that 

    represents the local time.

  

   Returns: An object that represents the date and time of the current System.DateTimeOffset object 

    converted to local time.
  """
  pass
 def ToOffset(self,offset):
  """
  ToOffset(self: DateTimeOffset,offset: TimeSpan) -> DateTimeOffset

  

   Converts the value of the current System.DateTimeOffset object to the date and time specified by 

    an offset value.

  

  

   offset: The offset to convert the System.DateTimeOffset value to.

   Returns: An object that is equal to the original System.DateTimeOffset object (that is,their 

    System.DateTimeOffset.ToUniversalTime methods return identical points in time) but whose 

    System.DateTimeOffset.Offset property is set to offset.
  """
  pass
 def ToString(self,*__args):
  """
  ToString(self: DateTimeOffset,formatProvider: IFormatProvider) -> str

  

   Converts the value of the current System.DateTimeOffset object to its equivalent string 

    representation using the specified culture-specific formatting information.

  

  

   formatProvider: An object that supplies culture-specific formatting information.

   Returns: A string representation of the value of the current System.DateTimeOffset object,as specified 

    by formatProvider.

  

  ToString(self: DateTimeOffset,format: str,formatProvider: IFormatProvider) -> str

  

   Converts the value of the current System.DateTimeOffset object to its equivalent string 

    representation using the specified format and culture-specific format information.

  

  

   format: A format string.

   formatProvider: An object that supplies culture-specific formatting information.

   Returns: A string representation of the value of the current System.DateTimeOffset object,as specified 

    by format and provider.

  

  ToString(self: DateTimeOffset) -> str

  

   Converts the value of the current System.DateTimeOffset object to its equivalent string 

    representation.

  

   Returns: A string representation of a System.DateTimeOffset object that includes the offset appended at 

    the end of the string.

  

  ToString(self: DateTimeOffset,format: str) -> str

  

   Converts the value of the current System.DateTimeOffset object to its equivalent string 

    representation using the specified format.

  

  

   format: A format string.

   Returns: A string representation of the value of the current System.DateTimeOffset object,as specified 

    by format.
  """
  pass
 def ToUniversalTime(self):
  """
  ToUniversalTime(self: DateTimeOffset) -> DateTimeOffset

  

   Converts the current System.DateTimeOffset object to a System.DateTimeOffset value that 

    represents the Coordinated Universal Time (UTC).

  

   Returns: An object that represents the date and time of the current System.DateTimeOffset object 

    converted to Coordinated Universal Time (UTC).
  """
  pass
 def ToUnixTimeMilliseconds(self):
  """ ToUnixTimeMilliseconds(self: DateTimeOffset) -> Int64 """
  pass
 def ToUnixTimeSeconds(self):
  """ ToUnixTimeSeconds(self: DateTimeOffset) -> Int64 """
  pass
 @staticmethod
 def TryParse(input,*__args):
  """
  TryParse(input: str,formatProvider: IFormatProvider,styles: DateTimeStyles) -> (bool,DateTimeOffset)

  

   Tries to convert a specified string representation of a date and time to its 

    System.DateTimeOffset equivalent,and returns a value that indicates whether the conversion 

    succeeded.

  

  

   input: A string that contains a date and time to convert.

   formatProvider: An object that provides culture-specific formatting information about input.

   styles: A bitwise combination of enumeration values that indicates the permitted format of input.

   Returns: true if the input parameter is successfully converted; otherwise,false.

  TryParse(input: str) -> (bool,DateTimeOffset)

  

   Tries to converts a specified string representation of a date and time to its 

    System.DateTimeOffset equivalent,and returns a value that indicates whether the conversion 

    succeeded.

  

  

   input: A string that contains a date and time to convert.

   Returns: true if the input parameter is successfully converted; otherwise,false.
  """
  pass
 @staticmethod
 def TryParseExact(input,*__args):
  """
  TryParseExact(input: str,formats: Array[str],formatProvider: IFormatProvider,styles: DateTimeStyles) -> (bool,DateTimeOffset)

  

   Converts the specified string representation of a date and time to its System.DateTimeOffset 

    equivalent using the specified array of formats,culture-specific format information,and style. 

    The format of the string representation must match one of the specified formats exactly.

  

  

   input: A string that contains a date and time to convert.

   formats: An array that defines the expected formats of input.

   formatProvider: An object that supplies culture-specific formatting information about input.

   styles: A bitwise combination of enumeration values that indicates the permitted format of input. A 

    typical value to specify is None.

  

   Returns: true if the input parameter is successfully converted; otherwise,false.

  TryParseExact(input: str,format: str,formatProvider: IFormatProvider,styles: DateTimeStyles) -> (bool,DateTimeOffset)

  

   Converts the specified string representation of a date and time to its System.DateTimeOffset 

    equivalent using the specified format,culture-specific format information,and style. The 

    format of the string representation must match the specified format exactly.

  

  

   input: A string that contains a date and time to convert.

   format: A format specifier that defines the required format of input.

   formatProvider: An object that supplies culture-specific formatting information about input.

   styles: A bitwise combination of enumeration values that indicates the permitted format of input. A 

    typical value to specify is None.

  

   Returns: true if the input parameter is successfully converted; otherwise,false.
  """
  pass
 def __add__(self,*args):
  """ x.__add__(y) <==> x+y """
  pass
 def __cmp__(self,*args):
  """ x.__cmp__(y) <==> cmp(x,y) """
  pass
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==y """
  pass
 def __format__(self,*args):
  """ __format__(formattable: IFormattable,format: str) -> str """
  pass
 def __ge__(self,*args):
  pass
 def __gt__(self,*args):
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __le__(self,*args):
  pass
 def __lt__(self,*args):
  pass
 @staticmethod
 def __new__(self,*__args):
  """
  __new__(cls: type,ticks: Int64,offset: TimeSpan)

  __new__(cls: type,dateTime: DateTime)

  __new__(cls: type,dateTime: DateTime,offset: TimeSpan)

  __new__(cls: type,year: int,month: int,day: int,hour: int,minute: int,second: int,offset: TimeSpan)

  __new__(cls: type,year: int,month: int,day: int,hour: int,minute: int,second: int,millisecond: int,offset: TimeSpan)

  __new__(cls: type,year: int,month: int,day: int,hour: int,minute: int,second: int,millisecond: int,calendar: Calendar,offset: TimeSpan)

  __new__[DateTimeOffset]() -> DateTimeOffset
  """
  pass
 def __ne__(self,*args):
  pass
 def __reduce_ex__(self,*args):
  pass
 def __repr__(self,*args):
  """ __repr__(self: object) -> str """
  pass
 def __rsub__(self,*args):
  """
  __rsub__(left: DateTimeOffset,right: DateTimeOffset) -> TimeSpan

  

   Subtracts one System.DateTimeOffset object from another and yields a time interval.

  

   left: The minuend.

   right: The subtrahend.

   Returns: An object that represents the difference between left and right.
  """
  pass
 def __str__(self,*args):
  pass
 def __sub__(self,*args):
  """ x.__sub__(y) <==> x-yx.__sub__(y) <==> x-y """
  pass
 Date=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a System.DateTime value that represents the date component of the current System.DateTimeOffset object.



Get: Date(self: DateTimeOffset) -> DateTime



"""

 DateTime=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a System.DateTime value that represents the date and time of the current System.DateTimeOffset object.



Get: DateTime(self: DateTimeOffset) -> DateTime



"""

 Day=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the day of the month represented by the current System.DateTimeOffset object.



Get: Day(self: DateTimeOffset) -> int



"""

 DayOfWeek=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the day of the week represented by the current System.DateTimeOffset object.



Get: DayOfWeek(self: DateTimeOffset) -> DayOfWeek



"""

 DayOfYear=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the day of the year represented by the current System.DateTimeOffset object.



Get: DayOfYear(self: DateTimeOffset) -> int



"""

 Hour=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the hour component of the time represented by the current System.DateTimeOffset object.



Get: Hour(self: DateTimeOffset) -> int



"""

 LocalDateTime=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a System.DateTime value that represents the local date and time of the current System.DateTimeOffset object.



Get: LocalDateTime(self: DateTimeOffset) -> DateTime



"""

 Millisecond=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the millisecond component of the time represented by the current System.DateTimeOffset object.



Get: Millisecond(self: DateTimeOffset) -> int



"""

 Minute=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the minute component of the time represented by the current System.DateTimeOffset object.



Get: Minute(self: DateTimeOffset) -> int



"""

 Month=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the month component of the date represented by the current System.DateTimeOffset object.



Get: Month(self: DateTimeOffset) -> int



"""

 Offset=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the time's offset from Coordinated Universal Time (UTC).



Get: Offset(self: DateTimeOffset) -> TimeSpan



"""

 Second=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the second component of the clock time represented by the current System.DateTimeOffset object.



Get: Second(self: DateTimeOffset) -> int



"""

 Ticks=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the number of ticks that represents the date and time of the current System.DateTimeOffset object in clock time.



Get: Ticks(self: DateTimeOffset) -> Int64



"""

 TimeOfDay=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the time of day for the current System.DateTimeOffset object.



Get: TimeOfDay(self: DateTimeOffset) -> TimeSpan



"""

 UtcDateTime=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a System.DateTime value that represents the Coordinated Universal Time (UTC) date and time of the current System.DateTimeOffset object.



Get: UtcDateTime(self: DateTimeOffset) -> DateTime



"""

 UtcTicks=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the number of ticks that represents the date and time of the current System.DateTimeOffset object in Coordinated Universal Time (UTC).



Get: UtcTicks(self: DateTimeOffset) -> Int64



"""

 Year=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the year component of the date represented by the current System.DateTimeOffset object.



Get: Year(self: DateTimeOffset) -> int



"""


 MaxValue=None
 MinValue=None
 Now=None
 UtcNow=None




class FlatButtonAppearance(object):
 """ Provides properties that specify the appearance of System.Windows.Forms.Button controls whose System.Windows.Forms.FlatStyle is System.Windows.Forms.FlatStyle.Flat. """
 BorderColor=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the color of the border around the button.



Get: BorderColor(self: FlatButtonAppearance) -> Color



Set: BorderColor(self: FlatButtonAppearance)=value

"""

 BorderSize=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets a value that specifies the size,in pixels,of the border around the button.



Get: BorderSize(self: FlatButtonAppearance) -> int



Set: BorderSize(self: FlatButtonAppearance)=value

"""

 CheckedBackColor=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the color of the client area of the button when the button is checked and the mouse pointer is outside the bounds of the control.



Get: CheckedBackColor(self: FlatButtonAppearance) -> Color



Set: CheckedBackColor(self: FlatButtonAppearance)=value

"""

 MouseDownBackColor=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the color of the client area of the button when the mouse is pressed within the bounds of the control.



Get: MouseDownBackColor(self: FlatButtonAppearance) -> Color



Set: MouseDownBackColor(self: FlatButtonAppearance)=value

"""

 MouseOverBackColor=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the color of the client area of the button when the mouse pointer is within the bounds of the control.



Get: MouseOverBackColor(self: FlatButtonAppearance) -> Color



Set: MouseOverBackColor(self: FlatButtonAppearance)=value

"""





class UIntPtr(object,ISerializable):
 """
 A platform-specific type that is used to represent a pointer or a handle.

 

 UIntPtr(value: UInt32)

 UIntPtr(value: UInt64)

 UIntPtr(value: Void*)
 """
 @staticmethod
 def Add(pointer,offset):
  """
  Add(pointer: UIntPtr,offset: int) -> UIntPtr

  

   Adds an offset to the value of an unsigned pointer.

  

   pointer: The unsigned pointer to add the offset to.

   offset: The offset to add.

   Returns: A new unsigned pointer that reflects the addition of offset to pointer.
  """
  pass
 def Equals(self,obj):
  """
  Equals(self: UIntPtr,obj: object) -> bool

  

   Returns a value indicating whether this instance is equal to a specified object.

  

   obj: An object to compare with this instance or null.

   Returns: true if obj is an instance of System.UIntPtr and equals the value of this instance; otherwise,

    false.
  """
  pass
 def GetHashCode(self):
  """
  GetHashCode(self: UIntPtr) -> int

  

   Returns the hash code for this instance.

   Returns: A 32-bit signed integer hash code.
  """
  pass
 @staticmethod
 def Subtract(pointer,offset):
  """
  Subtract(pointer: UIntPtr,offset: int) -> UIntPtr

  

   Subtracts an offset from the value of an unsigned pointer.

  

   pointer: The unsigned pointer to subtract the offset from.

   offset: The offset to subtract.

   Returns: A new unsigned pointer that reflects the subtraction of offset from pointer.
  """
  pass
 def ToPointer(self):
  """
  ToPointer(self: UIntPtr) -> Void*

  

   Converts the value of this instance to a pointer to an unspecified type.

   Returns: A pointer to System.Void; that is,a pointer to memory containing data of an unspecified type.
  """
  pass
 def ToString(self):
  """
  ToString(self: UIntPtr) -> str

  

   Converts the numeric value of this instance to its equivalent string representation.

   Returns: The string representation of the value of this instance.
  """
  pass
 def ToUInt32(self):
  """
  ToUInt32(self: UIntPtr) -> UInt32

  

   Converts the value of this instance to a 32-bit unsigned integer.

   Returns: A 32-bit unsigned integer equal to the value of this instance.
  """
  pass
 def ToUInt64(self):
  """
  ToUInt64(self: UIntPtr) -> UInt64

  

   Converts the value of this instance to a 64-bit unsigned integer.

   Returns: A 64-bit unsigned integer equal to the value of this instance.
  """
  pass
 def __add__(self,*args):
  """ x.__add__(y) <==> x+y """
  pass
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==y """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 @staticmethod
 def __new__(self,value):
  """
  __new__(cls: type,value: UInt32)

  __new__(cls: type,value: UInt64)

  __new__(cls: type,value: Void*)

  __new__[UIntPtr]() -> UIntPtr
  """
  pass
 def __ne__(self,*args):
  pass
 def __reduce_ex__(self,*args):
  pass
 def __repr__(self,*args):
  """ __repr__(self: object) -> str """
  pass
 def __str__(self,*args):
  pass
 def __sub__(self,*args):
  """ x.__sub__(y) <==> x-y """
  pass
 Size=4
 Zero=None




class TextChange(object):
 """ Contains information about the changes that occur in the System.Windows.Controls.Primitives.TextBoxBase.TextChanged event. """
 AddedLength=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the number of symbols that have been added to the control.



Get: AddedLength(self: TextChange) -> int



"""

 Offset=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the position at which the change occurred.



Get: Offset(self: TextChange) -> int



"""

 RemovedLength=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the number of symbols that have been removed from the control.



Get: RemovedLength(self: TextChange) -> int



"""





# encoding: utf-8
# module System.Net calls itself Net
# from System,Version=4.0.0.0,Culture=neutral,PublicKeyToken=b77a5c561934e089
# by generator 1.145
""" NamespaceTracker represent a CLS namespace. """
# no imports

# no functions
# classes
from __init___parts.AuthenticationManager import AuthenticationManager
from __init___parts.AuthenticationSchemes import AuthenticationSchemes
from __init___parts.AuthenticationSchemeSelector import AuthenticationSchemeSelector
from __init___parts.Authorization import Authorization
from __init___parts.BindIPEndPoint import BindIPEndPoint
from __init___parts.Cookie import Cookie
from __init___parts.CookieCollection import CookieCollection
from __init___parts.CookieContainer import CookieContainer
from __init___parts.CookieException import CookieException
from __init___parts.CredentialCache import CredentialCache
from __init___parts.DecompressionMethods import DecompressionMethods
from __init___parts.Dns import Dns
from __init___parts.EndPoint import EndPoint
from __init___parts.DnsEndPoint import DnsEndPoint
from __init___parts.DnsPermission import DnsPermission
from __init___parts.DnsPermissionAttribute import DnsPermissionAttribute
from __init___parts.DownloadDataCompletedEventArgs import DownloadDataCompletedEventArgs
from __init___parts.DownloadDataCompletedEventHandler import DownloadDataCompletedEventHandler
from __init___parts.DownloadProgressChangedEventArgs import DownloadProgressChangedEventArgs
from __init___parts.DownloadProgressChangedEventHandler import DownloadProgressChangedEventHandler
from __init___parts.DownloadStringCompletedEventArgs import DownloadStringCompletedEventArgs
from __init___parts.DownloadStringCompletedEventHandler import DownloadStringCompletedEventHandler
from __init___parts.EndpointPermission import EndpointPermission
from __init___parts.WebRequest import WebRequest
from __init___parts.FileWebRequest import FileWebRequest
from __init___parts.WebResponse import WebResponse
from __init___parts.FileWebResponse import FileWebResponse
from __init___parts.FtpStatusCode import FtpStatusCode
from __init___parts.FtpWebRequest import FtpWebRequest
from __init___parts.FtpWebResponse import FtpWebResponse
from __init___parts.GlobalProxySelection import GlobalProxySelection
from __init___parts.HttpContinueDelegate import HttpContinueDelegate
from __init___parts.HttpListener import HttpListener
from __init___parts.HttpListenerBasicIdentity import HttpListenerBasicIdentity
from __init___parts.HttpListenerContext import HttpListenerContext
from __init___parts.HttpListenerException import HttpListenerException
from __init___parts.HttpListenerPrefixCollection import HttpListenerPrefixCollection
from __init___parts.HttpListenerRequest import HttpListenerRequest
from __init___parts.HttpListenerResponse import HttpListenerResponse
from __init___parts.HttpListenerTimeoutManager import HttpListenerTimeoutManager
from __init___parts.HttpRequestHeader import HttpRequestHeader
from __init___parts.HttpResponseHeader import HttpResponseHeader
from __init___parts.HttpStatusCode import HttpStatusCode
from __init___parts.HttpVersion import HttpVersion
from __init___parts.HttpWebRequest import HttpWebRequest
from __init___parts.HttpWebResponse import HttpWebResponse
from __init___parts.IAuthenticationModule import IAuthenticationModule
from __init___parts.ICertificatePolicy import ICertificatePolicy
from __init___parts.ICredentialPolicy import ICredentialPolicy
from __init___parts.ICredentials import ICredentials
from __init___parts.ICredentialsByHost import ICredentialsByHost
from __init___parts.IPAddress import IPAddress
from __init___parts.IPEndPoint import IPEndPoint
from __init___parts.IPHostEntry import IPHostEntry
from __init___parts.IWebProxy import IWebProxy
from __init___parts.IWebProxyScript import IWebProxyScript
from __init___parts.IWebRequestCreate import IWebRequestCreate
from __init___parts.NetworkAccess import NetworkAccess
from __init___parts.NetworkCredential import NetworkCredential
from __init___parts.OpenReadCompletedEventArgs import OpenReadCompletedEventArgs
from __init___parts.OpenReadCompletedEventHandler import OpenReadCompletedEventHandler
from __init___parts.OpenWriteCompletedEventArgs import OpenWriteCompletedEventArgs
from __init___parts.OpenWriteCompletedEventHandler import OpenWriteCompletedEventHandler
from __init___parts.ProtocolViolationException import ProtocolViolationException
from __init___parts.SecurityProtocolType import SecurityProtocolType
from __init___parts.ServicePoint import ServicePoint
from __init___parts.ServicePointManager import ServicePointManager
from __init___parts.SocketAddress import SocketAddress
from __init___parts.SocketPermission import SocketPermission
from __init___parts.SocketPermissionAttribute import SocketPermissionAttribute
from __init___parts.TransportContext import TransportContext
from __init___parts.TransportType import TransportType
from __init___parts.UploadDataCompletedEventArgs import UploadDataCompletedEventArgs
from __init___parts.UploadDataCompletedEventHandler import UploadDataCompletedEventHandler
from __init___parts.UploadFileCompletedEventArgs import UploadFileCompletedEventArgs
from __init___parts.UploadFileCompletedEventHandler import UploadFileCompletedEventHandler
from __init___parts.UploadProgressChangedEventArgs import UploadProgressChangedEventArgs
from __init___parts.UploadProgressChangedEventHandler import UploadProgressChangedEventHandler
from __init___parts.UploadStringCompletedEventArgs import UploadStringCompletedEventArgs
from __init___parts.UploadStringCompletedEventHandler import UploadStringCompletedEventHandler
from __init___parts.UploadValuesCompletedEventArgs import UploadValuesCompletedEventArgs
from __init___parts.UploadValuesCompletedEventHandler import UploadValuesCompletedEventHandler
from __init___parts.WebClient import WebClient
from __init___parts.WebException import WebException
from __init___parts.WebExceptionStatus import WebExceptionStatus
from __init___parts.WebHeaderCollection import WebHeaderCollection
from __init___parts.WebPermission import WebPermission
from __init___parts.WebPermissionAttribute import WebPermissionAttribute
from __init___parts.WebProxy import WebProxy
from __init___parts.WebRequestMethods import WebRequestMethods
from __init___parts.WebUtility import WebUtility
from __init___parts.WriteStreamClosedEventArgs import WriteStreamClosedEventArgs
from __init___parts.WriteStreamClosedEventHandler import WriteStreamClosedEventHandler



class OpenWriteCompletedEventArgs(AsyncCompletedEventArgs):
 """ Provides data for the System.Net.WebClient.OpenWriteCompleted event. """
 Result=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a writable stream that is used to send data to a server.



Get: Result(self: OpenWriteCompletedEventArgs) -> Stream



"""





class SoundPlayerAction(TriggerAction,IDisposable):
 """
 Represents a lightweight audio playback System.Windows.TriggerAction used to play .wav files.

 

 SoundPlayerAction()
 """
 def Dispose(self):
  """
  Dispose(self: SoundPlayerAction)

   Releases the resources used by the System.Windows.Controls.SoundPlayerAction class.
  """
  pass
 def OnPropertyChanged(self,*args):
  """
  OnPropertyChanged(self: DependencyObject,e: DependencyPropertyChangedEventArgs)

   Invoked whenever the effective value of any dependency property on this 

    System.Windows.DependencyObject has been updated. The specific dependency property that changed 

    is reported in the event data.

  

  

   e: Event data that will contain the dependency property identifier of interest,the property 

    metadata for the type,and old and new values.
  """
  pass
 def ShouldSerializeProperty(self,*args):
  """
  ShouldSerializeProperty(self: DependencyObject,dp: DependencyProperty) -> bool

  

   Returns a value that indicates whether serialization processes should serialize the value for 

    the provided dependency property.

  

  

   dp: The identifier for the dependency property that should be serialized.

   Returns: true if the dependency property that is supplied should be value-serialized; otherwise,false.
  """
  pass
 def __enter__(self,*args):
  """
  __enter__(self: IDisposable) -> object

  

   Provides the implementation of __enter__ for objects which implement IDisposable.
  """
  pass
 def __exit__(self,*args):
  """
  __exit__(self: IDisposable,exc_type: object,exc_value: object,exc_back: object)

   Provides the implementation of __exit__ for objects which implement IDisposable.
  """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 Source=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the audio source location.



Get: Source(self: SoundPlayerAction) -> Uri



Set: Source(self: SoundPlayerAction)=value

"""


 SourceProperty=None




class FormattableString(object,IFormattable):
 # no doc
 def GetArgument(self,index):
  """ GetArgument(self: FormattableString,index: int) -> object """
  pass
 def GetArguments(self):
  """ GetArguments(self: FormattableString) -> Array[object] """
  pass
 @staticmethod
 def Invariant(formattable):
  """ Invariant(formattable: FormattableString) -> str """
  pass
 def ToString(self,formatProvider=None):
  """
  ToString(self: FormattableString) -> str

  ToString(self: FormattableString,formatProvider: IFormatProvider) -> str
  """
  pass
 def __format__(self,*args):
  """ __format__(formattable: IFormattable,format: str) -> str """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __repr__(self,*args):
  """ __repr__(self: object) -> str """
  pass
 def __str__(self,*args):
  pass
 ArgumentCount=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Get: ArgumentCount(self: FormattableString) -> int



"""

 Format=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Get: Format(self: FormattableString) -> str



"""





class DataGridViewColumnDividerDoubleClickEventArgs(HandledMouseEventArgs):
 """
 Provides data for the System.Windows.Forms.DataGridView.ColumnDividerDoubleClick event of a System.Windows.Forms.DataGridView.

 

 DataGridViewColumnDividerDoubleClickEventArgs(columnIndex: int,e: HandledMouseEventArgs)
 """
 @staticmethod
 def __new__(self,columnIndex,e):
  """ __new__(cls: type,columnIndex: int,e: HandledMouseEventArgs) """
  pass
 ColumnIndex=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """The index of the column next to the column divider that was double-clicked.



Get: ColumnIndex(self: DataGridViewColumnDividerDoubleClickEventArgs) -> int



"""





class SystemAcl(CommonAcl,ICollection,IEnumerable):
 """
 Represents a System Access Control List (SACL).

 

 SystemAcl(isContainer: bool,isDS: bool,capacity: int)

 SystemAcl(isContainer: bool,isDS: bool,revision: Byte,capacity: int)

 SystemAcl(isContainer: bool,isDS: bool,rawAcl: RawAcl)
 """
 def AddAudit(self,*__args):
  """
  AddAudit(self: SystemAcl,auditFlags: AuditFlags,sid: SecurityIdentifier,accessMask: int,inheritanceFlags: InheritanceFlags,propagationFlags: PropagationFlags,objectFlags: ObjectAceFlags,objectType: Guid,inheritedObjectType: Guid)

   Adds an audit rule with the specified settings to the current 

    System.Security.AccessControl.SystemAcl object. Use this method for directory object Access 

    Control Lists (ACLs) when specifying the object type or the inherited object type for the new 

    audit rule.

  

  

   auditFlags: The type of audit rule to add.

   sid: The System.Security.Principal.SecurityIdentifier for which to add an audit rule.

   accessMask: The access mask for the new audit rule.

   inheritanceFlags: Flags that specify the inheritance properties of the new audit rule.

   propagationFlags: Flags that specify the inheritance propagation properties for the new audit rule.

   objectFlags: Flags that specify if the objectType and inheritedObjectType parameters contain non-null values.

   objectType: The identity of the class of objects to which the new audit rule applies.

   inheritedObjectType: The identity of the class of child objects which can inherit the new audit rule.

  AddAudit(self: SystemAcl,sid: SecurityIdentifier,rule: ObjectAuditRule)AddAudit(self: SystemAcl,auditFlags: AuditFlags,sid: SecurityIdentifier,accessMask: int,inheritanceFlags: InheritanceFlags,propagationFlags: PropagationFlags)

   Adds an audit rule to the current System.Security.AccessControl.SystemAcl object.

  

   auditFlags: The type of audit rule to add.

   sid: The System.Security.Principal.SecurityIdentifier for which to add an audit rule.

   accessMask: The access mask for the new audit rule.

   inheritanceFlags: Flags that specify the inheritance properties of the new audit rule.

   propagationFlags: Flags that specify the inheritance propagation properties for the new audit rule.
  """
  pass
 def RemoveAudit(self,*__args):
  """
  RemoveAudit(self: SystemAcl,auditFlags: AuditFlags,sid: SecurityIdentifier,accessMask: int,inheritanceFlags: InheritanceFlags,propagationFlags: PropagationFlags,objectFlags: ObjectAceFlags,objectType: Guid,inheritedObjectType: Guid) -> bool

  

   Removes the specified audit rule from the current System.Security.AccessControl.SystemAcl 

    object. Use this method for directory object Access Control Lists (ACLs) when specifying the 

    object type or the inherited object type.

  

  

   auditFlags: The type of audit rule to remove.

   sid: The System.Security.Principal.SecurityIdentifier for which to remove an audit rule.

   accessMask: The access mask for the rule to be removed.

   inheritanceFlags: Flags that specify the inheritance properties of the rule to be removed.

   propagationFlags: Flags that specify the inheritance propagation properties for the rule to be removed.

   objectFlags: Flags that specify if the objectType and inheritedObjectType parameters contain non-null values.

   objectType: The identity of the class of objects to which the removed audit control rule applies.

   inheritedObjectType: The identity of the class of child objects which can inherit the removed audit rule.

   Returns: true if this method successfully removes the specified audit rule; otherwise,false.

  RemoveAudit(self: SystemAcl,sid: SecurityIdentifier,rule: ObjectAuditRule) -> bool

  RemoveAudit(self: SystemAcl,auditFlags: AuditFlags,sid: SecurityIdentifier,accessMask: int,inheritanceFlags: InheritanceFlags,propagationFlags: PropagationFlags) -> bool

  

   Removes the specified audit rule from the current System.Security.AccessControl.SystemAcl object.

  

   auditFlags: The type of audit rule to remove.

   sid: The System.Security.Principal.SecurityIdentifier for which to remove an audit rule.

   accessMask: The access mask for the rule to be removed.

   inheritanceFlags: Flags that specify the inheritance properties of the rule to be removed.

   propagationFlags: Flags that specify the inheritance propagation properties for the rule to be removed.

   Returns: true if this method successfully removes the specified audit rule; otherwise,false.
  """
  pass
 def RemoveAuditSpecific(self,*__args):
  """
  RemoveAuditSpecific(self: SystemAcl,auditFlags: AuditFlags,sid: SecurityIdentifier,accessMask: int,inheritanceFlags: InheritanceFlags,propagationFlags: PropagationFlags,objectFlags: ObjectAceFlags,objectType: Guid,inheritedObjectType: Guid)

   Removes the specified audit rule from the current System.Security.AccessControl.DiscretionaryAcl 

    object. Use this method for directory object Access Control Lists (ACLs) when specifying the 

    object type or the inherited object type.

  

  

   auditFlags: The type of audit rule to remove.

   sid: The System.Security.Principal.SecurityIdentifier for which to remove an audit rule.

   accessMask: The access mask for the rule to be removed.

   inheritanceFlags: Flags that specify the inheritance properties of the rule to be removed.

   propagationFlags: Flags that specify the inheritance propagation properties for the rule to be removed.

   objectFlags: Flags that specify if the objectType and inheritedObjectType parameters contain non-null values.

   objectType: The identity of the class of objects to which the removed audit control rule applies.

   inheritedObjectType: The identity of the class of child objects which can inherit the removed audit rule.

  RemoveAuditSpecific(self: SystemAcl,sid: SecurityIdentifier,rule: ObjectAuditRule)RemoveAuditSpecific(self: SystemAcl,auditFlags: AuditFlags,sid: SecurityIdentifier,accessMask: int,inheritanceFlags: InheritanceFlags,propagationFlags: PropagationFlags)

   Removes the specified audit rule from the current System.Security.AccessControl.DiscretionaryAcl 

    object.

  

  

   auditFlags: The type of audit rule to remove.

   sid: The System.Security.Principal.SecurityIdentifier for which to remove an audit rule.

   accessMask: The access mask for the rule to be removed.

   inheritanceFlags: Flags that specify the inheritance properties of the rule to be removed.

   propagationFlags: Flags that specify the inheritance propagation properties for the rule to be removed.
  """
  pass
 def SetAudit(self,*__args):
  """
  SetAudit(self: SystemAcl,auditFlags: AuditFlags,sid: SecurityIdentifier,accessMask: int,inheritanceFlags: InheritanceFlags,propagationFlags: PropagationFlags,objectFlags: ObjectAceFlags,objectType: Guid,inheritedObjectType: Guid)

   Sets the specified audit rule for the specified System.Security.Principal.SecurityIdentifier 

    object. Use this method for directory object Access Control Lists (ACLs) when specifying the 

    object type or the inherited object type.

  

  

   auditFlags: The audit condition to set.

   sid: The System.Security.Principal.SecurityIdentifier for which to set an audit rule.

   accessMask: The access mask for the new audit rule.

   inheritanceFlags: Flags that specify the inheritance properties of the new audit rule.

   propagationFlags: Flags that specify the inheritance propagation properties for the new audit rule.

   objectFlags: Flags that specify if the objectType and inheritedObjectType parameters contain non-null values.

   objectType: The identity of the class of objects to which the new audit rule applies.

   inheritedObjectType: The identity of the class of child objects which can inherit the new audit rule.

  SetAudit(self: SystemAcl,sid: SecurityIdentifier,rule: ObjectAuditRule)SetAudit(self: SystemAcl,auditFlags: AuditFlags,sid: SecurityIdentifier,accessMask: int,inheritanceFlags: InheritanceFlags,propagationFlags: PropagationFlags)

   Sets the specified audit rule for the specified System.Security.Principal.SecurityIdentifier 

    object.

  

  

   auditFlags: The audit condition to set.

   sid: The System.Security.Principal.SecurityIdentifier for which to set an audit rule.

   accessMask: The access mask for the new audit rule.

   inheritanceFlags: Flags that specify the inheritance properties of the new audit rule.

   propagationFlags: Flags that specify the inheritance propagation properties for the new audit rule.
  """
  pass
 def __getitem__(self,*args):
  """ x.__getitem__(y) <==> x[y] """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __iter__(self,*args):
  """ __iter__(self: IEnumerable) -> object """
  pass
 @staticmethod
 def __new__(self,isContainer,isDS,*__args):
  """
  __new__(cls: type,isContainer: bool,isDS: bool,capacity: int)

  __new__(cls: type,isContainer: bool,isDS: bool,revision: Byte,capacity: int)

  __new__(cls: type,isContainer: bool,isDS: bool,rawAcl: RawAcl)
  """
  pass
 def __setitem__(self,*args):
  """ x.__setitem__(i,y) <==> x[i]= """
  pass




# encoding: utf-8
# module System.Windows.Forms calls itself Forms
# from System.Windows.Forms,Version=4.0.0.0,Culture=neutral,PublicKeyToken=b77a5c561934e089
# by generator 1.145
""" NamespaceTracker represent a CLS namespace. """
# no imports

# no functions
# classes
from __init___parts.AccessibleEvents import AccessibleEvents
from __init___parts.AccessibleNavigation import AccessibleNavigation
from __init___parts.AccessibleObject import AccessibleObject
from __init___parts.AccessibleRole import AccessibleRole
from __init___parts.AccessibleSelection import AccessibleSelection
from __init___parts.AccessibleStates import AccessibleStates
from __init___parts.AmbientProperties import AmbientProperties
from __init___parts.AnchorStyles import AnchorStyles
from __init___parts.Appearance import Appearance
from __init___parts.Application import Application
from __init___parts.ApplicationContext import ApplicationContext
from __init___parts.ArrangeDirection import ArrangeDirection
from __init___parts.ArrangeStartingPosition import ArrangeStartingPosition
from __init___parts.ArrowDirection import ArrowDirection
from __init___parts.AutoCompleteMode import AutoCompleteMode
from __init___parts.AutoCompleteSource import AutoCompleteSource
from __init___parts.AutoCompleteStringCollection import AutoCompleteStringCollection
from __init___parts.AutoScaleMode import AutoScaleMode
from __init___parts.AutoSizeMode import AutoSizeMode
from __init___parts.AutoValidate import AutoValidate
from __init___parts.IBindableComponent import IBindableComponent
from __init___parts.IDropTarget import IDropTarget
from __init___parts.IWin32Window import IWin32Window
from __init___parts.Control import Control
from __init___parts.AxHost import AxHost
from __init___parts.BaseCollection import BaseCollection
from __init___parts.BatteryChargeStatus import BatteryChargeStatus
from __init___parts.Binding import Binding
from __init___parts.BindingCompleteContext import BindingCompleteContext
from __init___parts.BindingCompleteEventArgs import BindingCompleteEventArgs
from __init___parts.BindingCompleteEventHandler import BindingCompleteEventHandler
from __init___parts.BindingCompleteState import BindingCompleteState
from __init___parts.BindingContext import BindingContext
from __init___parts.BindingManagerBase import BindingManagerBase
from __init___parts.BindingManagerDataErrorEventArgs import BindingManagerDataErrorEventArgs
from __init___parts.BindingManagerDataErrorEventHandler import BindingManagerDataErrorEventHandler
from __init___parts.BindingMemberInfo import BindingMemberInfo
from __init___parts.ScrollableControl import ScrollableControl
from __init___parts.ToolStrip import ToolStrip
from __init___parts.BindingNavigator import BindingNavigator
from __init___parts.BindingsCollection import BindingsCollection
from __init___parts.ICurrencyManagerProvider import ICurrencyManagerProvider
from __init___parts.BindingSource import BindingSource
from __init___parts.BootMode import BootMode
from __init___parts.Border3DSide import Border3DSide
from __init___parts.Border3DStyle import Border3DStyle
from __init___parts.BorderStyle import BorderStyle
from __init___parts.BoundsSpecified import BoundsSpecified
from __init___parts.ButtonBase import ButtonBase
from __init___parts.IButtonControl import IButtonControl
from __init___parts.Button import Button
from __init___parts.ButtonBorderStyle import ButtonBorderStyle
from __init___parts.ButtonRenderer import ButtonRenderer
from __init___parts.ButtonState import ButtonState
from __init___parts.CacheVirtualItemsEventArgs import CacheVirtualItemsEventArgs
from __init___parts.CacheVirtualItemsEventHandler import CacheVirtualItemsEventHandler
from __init___parts.CaptionButton import CaptionButton
from __init___parts.CharacterCasing import CharacterCasing
from __init___parts.CheckBox import CheckBox
from __init___parts.CheckBoxRenderer import CheckBoxRenderer
from __init___parts.ListControl import ListControl
from __init___parts.ListBox import ListBox
from __init___parts.CheckedListBox import CheckedListBox
from __init___parts.CheckState import CheckState
from __init___parts.Clipboard import Clipboard
from __init___parts.CloseReason import CloseReason
from __init___parts.ColorDepth import ColorDepth
from __init___parts.CommonDialog import CommonDialog
from __init___parts.ColorDialog import ColorDialog
from __init___parts.ColumnClickEventArgs import ColumnClickEventArgs
from __init___parts.ColumnClickEventHandler import ColumnClickEventHandler
from __init___parts.ColumnHeader import ColumnHeader
from __init___parts.ColumnHeaderAutoResizeStyle import ColumnHeaderAutoResizeStyle
from __init___parts.ColumnHeaderConverter import ColumnHeaderConverter
from __init___parts.ColumnHeaderStyle import ColumnHeaderStyle
from __init___parts.ColumnReorderedEventArgs import ColumnReorderedEventArgs
from __init___parts.ColumnReorderedEventHandler import ColumnReorderedEventHandler
from __init___parts.TableLayoutStyle import TableLayoutStyle
from __init___parts.ColumnStyle import ColumnStyle
from __init___parts.ColumnWidthChangedEventArgs import ColumnWidthChangedEventArgs
from __init___parts.ColumnWidthChangedEventHandler import ColumnWidthChangedEventHandler
from __init___parts.ColumnWidthChangingEventArgs import ColumnWidthChangingEventArgs
from __init___parts.ColumnWidthChangingEventHandler import ColumnWidthChangingEventHandler
from __init___parts.ComboBox import ComboBox
from __init___parts.ComboBoxRenderer import ComboBoxRenderer
from __init___parts.ComboBoxStyle import ComboBoxStyle
from __init___parts.IContainerControl import IContainerControl
from __init___parts.ContainerControl import ContainerControl
from __init___parts.ContentsResizedEventArgs import ContentsResizedEventArgs
from __init___parts.ContentsResizedEventHandler import ContentsResizedEventHandler
from __init___parts.Menu import Menu
from __init___parts.ContextMenu import ContextMenu
from __init___parts.ToolStripDropDown import ToolStripDropDown
from __init___parts.ToolStripDropDownMenu import ToolStripDropDownMenu
from __init___parts.ContextMenuStrip import ContextMenuStrip
from __init___parts.ControlBindingsCollection import ControlBindingsCollection
from __init___parts.ControlEventArgs import ControlEventArgs
from __init___parts.ControlEventHandler import ControlEventHandler
from __init___parts.ControlPaint import ControlPaint
from __init___parts.ControlStyles import ControlStyles
from __init___parts.ControlUpdateMode import ControlUpdateMode
from __init___parts.ConvertEventArgs import ConvertEventArgs
from __init___parts.ConvertEventHandler import ConvertEventHandler
from __init___parts.CreateParams import CreateParams
from __init___parts.CurrencyManager import CurrencyManager
from __init___parts.Cursor import Cursor
from __init___parts.CursorConverter import CursorConverter
from __init___parts.Cursors import Cursors
from __init___parts.DataFormats import DataFormats
from __init___parts.IDataGridEditingService import IDataGridEditingService
from __init___parts.DataGrid import DataGrid
from __init___parts.IDataGridColumnStyleEditingNotificationService import IDataGridColumnStyleEditingNotificationService
from __init___parts.DataGridColumnStyle import DataGridColumnStyle
from __init___parts.DataGridBoolColumn import DataGridBoolColumn
from __init___parts.DataGridCell import DataGridCell
from __init___parts.DataGridLineStyle import DataGridLineStyle
from __init___parts.DataGridParentRowsLabelStyle import DataGridParentRowsLabelStyle
from __init___parts.DataGridPreferredColumnWidthTypeConverter import DataGridPreferredColumnWidthTypeConverter
from __init___parts.DataGridTableStyle import DataGridTableStyle
from __init___parts.TextBoxBase import TextBoxBase
from __init___parts.TextBox import TextBox
from __init___parts.DataGridTextBox import DataGridTextBox
from __init___parts.DataGridTextBoxColumn import DataGridTextBoxColumn
from __init___parts.DataGridView import DataGridView
from __init___parts.DataGridViewAdvancedBorderStyle import DataGridViewAdvancedBorderStyle
from __init___parts.DataGridViewAdvancedCellBorderStyle import DataGridViewAdvancedCellBorderStyle
from __init___parts.DataGridViewAutoSizeColumnMode import DataGridViewAutoSizeColumnMode
from __init___parts.DataGridViewAutoSizeColumnModeEventArgs import DataGridViewAutoSizeColumnModeEventArgs
from __init___parts.DataGridViewAutoSizeColumnModeEventHandler import DataGridViewAutoSizeColumnModeEventHandler
from __init___parts.DataGridViewAutoSizeColumnsMode import DataGridViewAutoSizeColumnsMode
from __init___parts.DataGridViewAutoSizeColumnsModeEventArgs import DataGridViewAutoSizeColumnsModeEventArgs
from __init___parts.DataGridViewAutoSizeColumnsModeEventHandler import DataGridViewAutoSizeColumnsModeEventHandler
from __init___parts.DataGridViewAutoSizeModeEventArgs import DataGridViewAutoSizeModeEventArgs
from __init___parts.DataGridViewAutoSizeModeEventHandler import DataGridViewAutoSizeModeEventHandler
from __init___parts.DataGridViewAutoSizeRowMode import DataGridViewAutoSizeRowMode
from __init___parts.DataGridViewAutoSizeRowsMode import DataGridViewAutoSizeRowsMode
from __init___parts.DataGridViewElement import DataGridViewElement
from __init___parts.DataGridViewBand import DataGridViewBand
from __init___parts.DataGridViewBindingCompleteEventArgs import DataGridViewBindingCompleteEventArgs
from __init___parts.DataGridViewBindingCompleteEventHandler import DataGridViewBindingCompleteEventHandler
from __init___parts.DataGridViewCell import DataGridViewCell
from __init___parts.DataGridViewButtonCell import DataGridViewButtonCell
from __init___parts.DataGridViewColumn import DataGridViewColumn
from __init___parts.DataGridViewButtonColumn import DataGridViewButtonColumn
from __init___parts.DataGridViewCellBorderStyle import DataGridViewCellBorderStyle
from __init___parts.DataGridViewCellCancelEventArgs import DataGridViewCellCancelEventArgs
from __init___parts.DataGridViewCellCancelEventHandler import DataGridViewCellCancelEventHandler
from __init___parts.DataGridViewCellCollection import DataGridViewCellCollection
from __init___parts.DataGridViewCellEventArgs import DataGridViewCellEventArgs
from __init___parts.DataGridViewCellContextMenuStripNeededEventArgs import DataGridViewCellContextMenuStripNeededEventArgs
from __init___parts.DataGridViewCellContextMenuStripNeededEventHandler import DataGridViewCellContextMenuStripNeededEventHandler
from __init___parts.DataGridViewCellErrorTextNeededEventArgs import DataGridViewCellErrorTextNeededEventArgs
from __init___parts.DataGridViewCellErrorTextNeededEventHandler import DataGridViewCellErrorTextNeededEventHandler
from __init___parts.DataGridViewCellEventHandler import DataGridViewCellEventHandler
from __init___parts.DataGridViewCellFormattingEventArgs import DataGridViewCellFormattingEventArgs
from __init___parts.DataGridViewCellFormattingEventHandler import DataGridViewCellFormattingEventHandler
from __init___parts.MouseEventArgs import MouseEventArgs
from __init___parts.DataGridViewCellMouseEventArgs import DataGridViewCellMouseEventArgs
from __init___parts.DataGridViewCellMouseEventHandler import DataGridViewCellMouseEventHandler
from __init___parts.DataGridViewCellPaintingEventArgs import DataGridViewCellPaintingEventArgs
from __init___parts.DataGridViewCellPaintingEventHandler import DataGridViewCellPaintingEventHandler
from __init___parts.DataGridViewCellParsingEventArgs import DataGridViewCellParsingEventArgs
from __init___parts.DataGridViewCellParsingEventHandler import DataGridViewCellParsingEventHandler
from __init___parts.DataGridViewCellStateChangedEventArgs import DataGridViewCellStateChangedEventArgs
from __init___parts.DataGridViewCellStateChangedEventHandler import DataGridViewCellStateChangedEventHandler
from __init___parts.DataGridViewCellStyle import DataGridViewCellStyle
from __init___parts.DataGridViewCellStyleContentChangedEventArgs import DataGridViewCellStyleContentChangedEventArgs
from __init___parts.DataGridViewCellStyleContentChangedEventHandler import DataGridViewCellStyleContentChangedEventHandler
from __init___parts.DataGridViewCellStyleConverter import DataGridViewCellStyleConverter
from __init___parts.DataGridViewCellStyleScopes import DataGridViewCellStyleScopes
from __init___parts.DataGridViewCellToolTipTextNeededEventArgs import DataGridViewCellToolTipTextNeededEventArgs
from __init___parts.DataGridViewCellToolTipTextNeededEventHandler import DataGridViewCellToolTipTextNeededEventHandler
from __init___parts.DataGridViewCellValidatingEventArgs import DataGridViewCellValidatingEventArgs
from __init___parts.DataGridViewCellValidatingEventHandler import DataGridViewCellValidatingEventHandler
from __init___parts.DataGridViewCellValueEventArgs import DataGridViewCellValueEventArgs
from __init___parts.DataGridViewCellValueEventHandler import DataGridViewCellValueEventHandler
from __init___parts.DataGridViewCheckBoxCell import DataGridViewCheckBoxCell
from __init___parts.DataGridViewCheckBoxColumn import DataGridViewCheckBoxColumn
from __init___parts.DataGridViewClipboardCopyMode import DataGridViewClipboardCopyMode
from __init___parts.DataGridViewColumnCollection import DataGridViewColumnCollection
from __init___parts.DataGridViewColumnDesignTimeVisibleAttribute import DataGridViewColumnDesignTimeVisibleAttribute
from __init___parts.HandledMouseEventArgs import HandledMouseEventArgs
from __init___parts.DataGridViewColumnDividerDoubleClickEventArgs import DataGridViewColumnDividerDoubleClickEventArgs
from __init___parts.DataGridViewColumnDividerDoubleClickEventHandler import DataGridViewColumnDividerDoubleClickEventHandler
from __init___parts.DataGridViewColumnEventArgs import DataGridViewColumnEventArgs
from __init___parts.DataGridViewColumnEventHandler import DataGridViewColumnEventHandler
from __init___parts.DataGridViewHeaderCell import DataGridViewHeaderCell
from __init___parts.DataGridViewColumnHeaderCell import DataGridViewColumnHeaderCell
from __init___parts.DataGridViewColumnHeadersHeightSizeMode import DataGridViewColumnHeadersHeightSizeMode
from __init___parts.DataGridViewColumnSortMode import DataGridViewColumnSortMode
from __init___parts.DataGridViewColumnStateChangedEventArgs import DataGridViewColumnStateChangedEventArgs
from __init___parts.DataGridViewColumnStateChangedEventHandler import DataGridViewColumnStateChangedEventHandler
from __init___parts.DataGridViewComboBoxCell import DataGridViewComboBoxCell
from __init___parts.DataGridViewComboBoxColumn import DataGridViewComboBoxColumn
from __init___parts.DataGridViewComboBoxDisplayStyle import DataGridViewComboBoxDisplayStyle
from __init___parts.IDataGridViewEditingControl import IDataGridViewEditingControl
from __init___parts.DataGridViewComboBoxEditingControl import DataGridViewComboBoxEditingControl
from __init___parts.DataGridViewContentAlignment import DataGridViewContentAlignment
from __init___parts.DataGridViewDataErrorContexts import DataGridViewDataErrorContexts
from __init___parts.DataGridViewDataErrorEventArgs import DataGridViewDataErrorEventArgs
from __init___parts.DataGridViewDataErrorEventHandler import DataGridViewDataErrorEventHandler
from __init___parts.DataGridViewEditingControlShowingEventArgs import DataGridViewEditingControlShowingEventArgs
from __init___parts.DataGridViewEditingControlShowingEventHandler import DataGridViewEditingControlShowingEventHandler
from __init___parts.DataGridViewEditMode import DataGridViewEditMode
from __init___parts.DataGridViewElementStates import DataGridViewElementStates
from __init___parts.DataGridViewHeaderBorderStyle import DataGridViewHeaderBorderStyle
from __init___parts.DataGridViewHitTestType import DataGridViewHitTestType
from __init___parts.DataGridViewImageCell import DataGridViewImageCell
from __init___parts.DataGridViewImageCellLayout import DataGridViewImageCellLayout
from __init___parts.DataGridViewImageColumn import DataGridViewImageColumn
from __init___parts.DataGridViewLinkCell import DataGridViewLinkCell
from __init___parts.DataGridViewLinkColumn import DataGridViewLinkColumn
from __init___parts.DataGridViewPaintParts import DataGridViewPaintParts
from __init___parts.DataGridViewRow import DataGridViewRow
from __init___parts.DataGridViewRowCancelEventArgs import DataGridViewRowCancelEventArgs
from __init___parts.DataGridViewRowCancelEventHandler import DataGridViewRowCancelEventHandler
from __init___parts.DataGridViewRowCollection import DataGridViewRowCollection
from __init___parts.DataGridViewRowContextMenuStripNeededEventArgs import DataGridViewRowContextMenuStripNeededEventArgs
from __init___parts.DataGridViewRowContextMenuStripNeededEventHandler import DataGridViewRowContextMenuStripNeededEventHandler
from __init___parts.DataGridViewRowDividerDoubleClickEventArgs import DataGridViewRowDividerDoubleClickEventArgs
from __init___parts.DataGridViewRowDividerDoubleClickEventHandler import DataGridViewRowDividerDoubleClickEventHandler
from __init___parts.DataGridViewRowErrorTextNeededEventArgs import DataGridViewRowErrorTextNeededEventArgs
from __init___parts.DataGridViewRowErrorTextNeededEventHandler import DataGridViewRowErrorTextNeededEventHandler
from __init___parts.DataGridViewRowEventArgs import DataGridViewRowEventArgs
from __init___parts.DataGridViewRowEventHandler import DataGridViewRowEventHandler
from __init___parts.DataGridViewRowHeaderCell import DataGridViewRowHeaderCell
from __init___parts.DataGridViewRowHeadersWidthSizeMode import DataGridViewRowHeadersWidthSizeMode
from __init___parts.DataGridViewRowHeightInfoNeededEventArgs import DataGridViewRowHeightInfoNeededEventArgs
from __init___parts.DataGridViewRowHeightInfoNeededEventHandler import DataGridViewRowHeightInfoNeededEventHandler
from __init___parts.DataGridViewRowHeightInfoPushedEventArgs import DataGridViewRowHeightInfoPushedEventArgs
from __init___parts.DataGridViewRowHeightInfoPushedEventHandler import DataGridViewRowHeightInfoPushedEventHandler
from __init___parts.DataGridViewRowPostPaintEventArgs import DataGridViewRowPostPaintEventArgs
from __init___parts.DataGridViewRowPostPaintEventHandler import DataGridViewRowPostPaintEventHandler
from __init___parts.DataGridViewRowPrePaintEventArgs import DataGridViewRowPrePaintEventArgs
from __init___parts.DataGridViewRowPrePaintEventHandler import DataGridViewRowPrePaintEventHandler
from __init___parts.DataGridViewRowsAddedEventArgs import DataGridViewRowsAddedEventArgs
from __init___parts.DataGridViewRowsAddedEventHandler import DataGridViewRowsAddedEventHandler
from __init___parts.DataGridViewRowsRemovedEventArgs import DataGridViewRowsRemovedEventArgs
from __init___parts.DataGridViewRowsRemovedEventHandler import DataGridViewRowsRemovedEventHandler
from __init___parts.DataGridViewRowStateChangedEventArgs import DataGridViewRowStateChangedEventArgs
from __init___parts.DataGridViewRowStateChangedEventHandler import DataGridViewRowStateChangedEventHandler
from __init___parts.DataGridViewSelectedCellCollection import DataGridViewSelectedCellCollection
from __init___parts.DataGridViewSelectedColumnCollection import DataGridViewSelectedColumnCollection
from __init___parts.DataGridViewSelectedRowCollection import DataGridViewSelectedRowCollection
from __init___parts.DataGridViewSelectionMode import DataGridViewSelectionMode
from __init___parts.DataGridViewSortCompareEventArgs import DataGridViewSortCompareEventArgs
from __init___parts.DataGridViewSortCompareEventHandler import DataGridViewSortCompareEventHandler
from __init___parts.DataGridViewTextBoxCell import DataGridViewTextBoxCell
from __init___parts.DataGridViewTextBoxColumn import DataGridViewTextBoxColumn
from __init___parts.DataGridViewTextBoxEditingControl import DataGridViewTextBoxEditingControl
from __init___parts.DataGridViewTopLeftHeaderCell import DataGridViewTopLeftHeaderCell
from __init___parts.DataGridViewTriState import DataGridViewTriState
from __init___parts.IDataObject import IDataObject
from __init___parts.DataObject import DataObject
from __init___parts.DataSourceUpdateMode import DataSourceUpdateMode
from __init___parts.DateBoldEventArgs import DateBoldEventArgs
from __init___parts.DateBoldEventHandler import DateBoldEventHandler
from __init___parts.DateRangeEventArgs import DateRangeEventArgs
from __init___parts.DateRangeEventHandler import DateRangeEventHandler
from __init___parts.DateTimePicker import DateTimePicker
from __init___parts.DateTimePickerFormat import DateTimePickerFormat
from __init___parts.Day import Day
from __init___parts.DialogResult import DialogResult
from __init___parts.DockingAttribute import DockingAttribute
from __init___parts.DockingBehavior import DockingBehavior
from __init___parts.DockStyle import DockStyle
from __init___parts.UpDownBase import UpDownBase
from __init___parts.DomainUpDown import DomainUpDown
from __init___parts.DpiChangedEventArgs import DpiChangedEventArgs
from __init___parts.DpiChangedEventHandler import DpiChangedEventHandler
from __init___parts.DragAction import DragAction
from __init___parts.DragDropEffects import DragDropEffects
from __init___parts.DragEventArgs import DragEventArgs
from __init___parts.DragEventHandler import DragEventHandler
from __init___parts.DrawItemEventArgs import DrawItemEventArgs
from __init___parts.DrawItemEventHandler import DrawItemEventHandler
from __init___parts.DrawItemState import DrawItemState
from __init___parts.DrawListViewColumnHeaderEventArgs import DrawListViewColumnHeaderEventArgs
from __init___parts.DrawListViewColumnHeaderEventHandler import DrawListViewColumnHeaderEventHandler
from __init___parts.DrawListViewItemEventArgs import DrawListViewItemEventArgs
from __init___parts.DrawListViewItemEventHandler import DrawListViewItemEventHandler
from __init___parts.DrawListViewSubItemEventArgs import DrawListViewSubItemEventArgs
from __init___parts.DrawListViewSubItemEventHandler import DrawListViewSubItemEventHandler
from __init___parts.DrawMode import DrawMode
from __init___parts.DrawToolTipEventArgs import DrawToolTipEventArgs
from __init___parts.DrawToolTipEventHandler import DrawToolTipEventHandler
from __init___parts.DrawTreeNodeEventArgs import DrawTreeNodeEventArgs
from __init___parts.DrawTreeNodeEventHandler import DrawTreeNodeEventHandler
from __init___parts.ErrorBlinkStyle import ErrorBlinkStyle
from __init___parts.ErrorIconAlignment import ErrorIconAlignment
from __init___parts.ErrorProvider import ErrorProvider
from __init___parts.FeatureSupport import FeatureSupport
from __init___parts.FileDialog import FileDialog
from __init___parts.FileDialogCustomPlace import FileDialogCustomPlace
from __init___parts.FileDialogCustomPlacesCollection import FileDialogCustomPlacesCollection
from __init___parts.FixedPanel import FixedPanel
from __init___parts.FlatButtonAppearance import FlatButtonAppearance
from __init___parts.FlatStyle import FlatStyle
from __init___parts.FlowDirection import FlowDirection
from __init___parts.Panel import Panel
from __init___parts.FlowLayoutPanel import FlowLayoutPanel
from __init___parts.LayoutSettings import LayoutSettings
from __init___parts.FlowLayoutSettings import FlowLayoutSettings
from __init___parts.FolderBrowserDialog import FolderBrowserDialog
from __init___parts.FontDialog import FontDialog
from __init___parts.Form import Form
from __init___parts.FormBorderStyle import FormBorderStyle
from __init___parts.FormClosedEventArgs import FormClosedEventArgs
from __init___parts.FormClosedEventHandler import FormClosedEventHandler
from __init___parts.FormClosingEventArgs import FormClosingEventArgs
from __init___parts.FormClosingEventHandler import FormClosingEventHandler
from __init___parts.FormCollection import FormCollection
from __init___parts.FormStartPosition import FormStartPosition
from __init___parts.FormWindowState import FormWindowState
from __init___parts.FrameStyle import FrameStyle
from __init___parts.GetChildAtPointSkip import GetChildAtPointSkip
from __init___parts.GiveFeedbackEventArgs import GiveFeedbackEventArgs
from __init___parts.GiveFeedbackEventHandler import GiveFeedbackEventHandler
from __init___parts.GridColumnStylesCollection import GridColumnStylesCollection
from __init___parts.GridItem import GridItem
from __init___parts.GridItemCollection import GridItemCollection
from __init___parts.GridItemType import GridItemType
from __init___parts.GridTablesFactory import GridTablesFactory
from __init___parts.GridTableStylesCollection import GridTableStylesCollection
from __init___parts.GroupBox import GroupBox
from __init___parts.GroupBoxRenderer import GroupBoxRenderer
from __init___parts.Help import Help
from __init___parts.HelpEventArgs import HelpEventArgs
from __init___parts.HelpEventHandler import HelpEventHandler
from __init___parts.HelpNavigator import HelpNavigator
from __init___parts.HelpProvider import HelpProvider
from __init___parts.HorizontalAlignment import HorizontalAlignment
from __init___parts.ScrollBar import ScrollBar
from __init___parts.HScrollBar import HScrollBar
from __init___parts.ScrollProperties import ScrollProperties
from __init___parts.HScrollProperties import HScrollProperties
from __init___parts.HtmlDocument import HtmlDocument
from __init___parts.HtmlElement import HtmlElement
from __init___parts.HtmlElementCollection import HtmlElementCollection
from __init___parts.HtmlElementErrorEventArgs import HtmlElementErrorEventArgs
from __init___parts.HtmlElementErrorEventHandler import HtmlElementErrorEventHandler
from __init___parts.HtmlElementEventArgs import HtmlElementEventArgs
from __init___parts.HtmlElementEventHandler import HtmlElementEventHandler
from __init___parts.HtmlElementInsertionOrientation import HtmlElementInsertionOrientation
from __init___parts.HtmlHistory import HtmlHistory
from __init___parts.HtmlWindow import HtmlWindow
from __init___parts.HtmlWindowCollection import HtmlWindowCollection
from __init___parts.ICommandExecutor import ICommandExecutor
from __init___parts.IComponentEditorPageSite import IComponentEditorPageSite
from __init___parts.IDataGridViewEditingCell import IDataGridViewEditingCell
from __init___parts.IFeatureSupport import IFeatureSupport
from __init___parts.IFileReaderService import IFileReaderService
from __init___parts.ImageIndexConverter import ImageIndexConverter
from __init___parts.ImageKeyConverter import ImageKeyConverter
from __init___parts.ImageLayout import ImageLayout
from __init___parts.ImageList import ImageList
from __init___parts.ImageListStreamer import ImageListStreamer
from __init___parts.ImeContext import ImeContext
from __init___parts.ImeMode import ImeMode
from __init___parts.ImeModeConversion import ImeModeConversion
from __init___parts.IMessageFilter import IMessageFilter
from __init___parts.InputLanguage import InputLanguage
from __init___parts.InputLanguageChangedEventArgs import InputLanguageChangedEventArgs
from __init___parts.InputLanguageChangedEventHandler import InputLanguageChangedEventHandler
from __init___parts.InputLanguageChangingEventArgs import InputLanguageChangingEventArgs
from __init___parts.InputLanguageChangingEventHandler import InputLanguageChangingEventHandler
from __init___parts.InputLanguageCollection import InputLanguageCollection
from __init___parts.InsertKeyMode import InsertKeyMode
from __init___parts.InvalidateEventArgs import InvalidateEventArgs
from __init___parts.InvalidateEventHandler import InvalidateEventHandler
from __init___parts.ItemActivation import ItemActivation
from __init___parts.ItemBoundsPortion import ItemBoundsPortion
from __init___parts.ItemChangedEventArgs import ItemChangedEventArgs
from __init___parts.ItemChangedEventHandler import ItemChangedEventHandler
from __init___parts.ItemCheckedEventArgs import ItemCheckedEventArgs
from __init___parts.ItemCheckedEventHandler import ItemCheckedEventHandler
from __init___parts.ItemCheckEventArgs import ItemCheckEventArgs
from __init___parts.ItemCheckEventHandler import ItemCheckEventHandler
from __init___parts.ItemDragEventArgs import ItemDragEventArgs
from __init___parts.ItemDragEventHandler import ItemDragEventHandler
from __init___parts.IWindowTarget import IWindowTarget
from __init___parts.KeyEventArgs import KeyEventArgs
from __init___parts.KeyEventHandler import KeyEventHandler
from __init___parts.KeyPressEventArgs import KeyPressEventArgs
from __init___parts.KeyPressEventHandler import KeyPressEventHandler
from __init___parts.Keys import Keys
from __init___parts.KeysConverter import KeysConverter
from __init___parts.Label import Label
from __init___parts.LabelEditEventArgs import LabelEditEventArgs
from __init___parts.LabelEditEventHandler import LabelEditEventHandler
from __init___parts.LayoutEventArgs import LayoutEventArgs
from __init___parts.LayoutEventHandler import LayoutEventHandler
from __init___parts.LeftRightAlignment import LeftRightAlignment
from __init___parts.LinkArea import LinkArea
from __init___parts.LinkBehavior import LinkBehavior
from __init___parts.LinkClickedEventArgs import LinkClickedEventArgs
from __init___parts.LinkClickedEventHandler import LinkClickedEventHandler
from __init___parts.LinkConverter import LinkConverter
from __init___parts.LinkLabel import LinkLabel
from __init___parts.LinkLabelLinkClickedEventArgs import LinkLabelLinkClickedEventArgs
from __init___parts.LinkLabelLinkClickedEventHandler import LinkLabelLinkClickedEventHandler
from __init___parts.LinkState import LinkState
from __init___parts.ListBindingConverter import ListBindingConverter
from __init___parts.ListBindingHelper import ListBindingHelper
from __init___parts.ListControlConvertEventArgs import ListControlConvertEventArgs
from __init___parts.ListControlConvertEventHandler import ListControlConvertEventHandler
from __init___parts.ListView import ListView
from __init___parts.ListViewAlignment import ListViewAlignment
from __init___parts.ListViewGroup import ListViewGroup
from __init___parts.ListViewGroupCollection import ListViewGroupCollection
from __init___parts.ListViewHitTestInfo import ListViewHitTestInfo
from __init___parts.ListViewHitTestLocations import ListViewHitTestLocations
from __init___parts.ListViewInsertionMark import ListViewInsertionMark
from __init___parts.ListViewItem import ListViewItem
from __init___parts.ListViewItemConverter import ListViewItemConverter
from __init___parts.ListViewItemMouseHoverEventArgs import ListViewItemMouseHoverEventArgs
from __init___parts.ListViewItemMouseHoverEventHandler import ListViewItemMouseHoverEventHandler
from __init___parts.ListViewItemSelectionChangedEventArgs import ListViewItemSelectionChangedEventArgs
from __init___parts.ListViewItemSelectionChangedEventHandler import ListViewItemSelectionChangedEventHandler
from __init___parts.ListViewItemStates import ListViewItemStates
from __init___parts.ListViewVirtualItemsSelectionRangeChangedEventArgs import ListViewVirtualItemsSelectionRangeChangedEventArgs
from __init___parts.ListViewVirtualItemsSelectionRangeChangedEventHandler import ListViewVirtualItemsSelectionRangeChangedEventHandler
from __init___parts.MainMenu import MainMenu
from __init___parts.MaskedTextBox import MaskedTextBox
from __init___parts.MaskFormat import MaskFormat
from __init___parts.MaskInputRejectedEventArgs import MaskInputRejectedEventArgs
from __init___parts.MaskInputRejectedEventHandler import MaskInputRejectedEventHandler
from __init___parts.MdiClient import MdiClient
from __init___parts.MdiLayout import MdiLayout
from __init___parts.MeasureItemEventArgs import MeasureItemEventArgs
from __init___parts.MeasureItemEventHandler import MeasureItemEventHandler
from __init___parts.MenuGlyph import MenuGlyph
from __init___parts.MenuItem import MenuItem
from __init___parts.MenuMerge import MenuMerge
from __init___parts.MenuStrip import MenuStrip
from __init___parts.MergeAction import MergeAction
from __init___parts.Message import Message
from __init___parts.MessageBox import MessageBox
from __init___parts.MessageBoxButtons import MessageBoxButtons
from __init___parts.MessageBoxDefaultButton import MessageBoxDefaultButton
from __init___parts.MessageBoxIcon import MessageBoxIcon
from __init___parts.MessageBoxOptions import MessageBoxOptions
from __init___parts.MethodInvoker import MethodInvoker
from __init___parts.MonthCalendar import MonthCalendar
from __init___parts.MouseButtons import MouseButtons
from __init___parts.MouseEventHandler import MouseEventHandler
from __init___parts.NativeWindow import NativeWindow
from __init___parts.NavigateEventArgs import NavigateEventArgs
from __init___parts.NavigateEventHandler import NavigateEventHandler
from __init___parts.NodeLabelEditEventArgs import NodeLabelEditEventArgs
from __init___parts.NodeLabelEditEventHandler import NodeLabelEditEventHandler
from __init___parts.NotifyIcon import NotifyIcon
from __init___parts.NumericUpDown import NumericUpDown
from __init___parts.NumericUpDownAcceleration import NumericUpDownAcceleration
from __init___parts.NumericUpDownAccelerationCollection import NumericUpDownAccelerationCollection
from __init___parts.OpacityConverter import OpacityConverter
from __init___parts.OpenFileDialog import OpenFileDialog
from __init___parts.Orientation import Orientation
from __init___parts.OSFeature import OSFeature
from __init___parts.OwnerDrawPropertyBag import OwnerDrawPropertyBag
from __init___parts.Padding import Padding
from __init___parts.PaddingConverter import PaddingConverter
from __init___parts.PageSetupDialog import PageSetupDialog
from __init___parts.PaintEventArgs import PaintEventArgs
from __init___parts.PaintEventHandler import PaintEventHandler
from __init___parts.PictureBox import PictureBox
from __init___parts.PictureBoxSizeMode import PictureBoxSizeMode
from __init___parts.PopupEventArgs import PopupEventArgs
from __init___parts.PopupEventHandler import PopupEventHandler
from __init___parts.PowerLineStatus import PowerLineStatus
from __init___parts.PowerState import PowerState
from __init___parts.PowerStatus import PowerStatus
from __init___parts.PreProcessControlState import PreProcessControlState
from __init___parts.PreviewKeyDownEventArgs import PreviewKeyDownEventArgs
from __init___parts.PreviewKeyDownEventHandler import PreviewKeyDownEventHandler
from __init___parts.PrintControllerWithStatusDialog import PrintControllerWithStatusDialog
from __init___parts.PrintDialog import PrintDialog
from __init___parts.PrintPreviewControl import PrintPreviewControl
from __init___parts.PrintPreviewDialog import PrintPreviewDialog
from __init___parts.ProfessionalColors import ProfessionalColors
from __init___parts.ProfessionalColorTable import ProfessionalColorTable
from __init___parts.ProgressBar import ProgressBar
from __init___parts.ProgressBarRenderer import ProgressBarRenderer
from __init___parts.ProgressBarStyle import ProgressBarStyle
from __init___parts.PropertyGrid import PropertyGrid
from __init___parts.PropertyManager import PropertyManager
from __init___parts.PropertySort import PropertySort
from __init___parts.PropertyTabChangedEventArgs import PropertyTabChangedEventArgs
from __init___parts.PropertyTabChangedEventHandler import PropertyTabChangedEventHandler
from __init___parts.PropertyValueChangedEventArgs import PropertyValueChangedEventArgs
from __init___parts.PropertyValueChangedEventHandler import PropertyValueChangedEventHandler
from __init___parts.QueryAccessibilityHelpEventArgs import QueryAccessibilityHelpEventArgs
from __init___parts.QueryAccessibilityHelpEventHandler import QueryAccessibilityHelpEventHandler
from __init___parts.QueryContinueDragEventArgs import QueryContinueDragEventArgs
from __init___parts.QueryContinueDragEventHandler import QueryContinueDragEventHandler
from __init___parts.QuestionEventArgs import QuestionEventArgs
from __init___parts.QuestionEventHandler import QuestionEventHandler
from __init___parts.RadioButton import RadioButton
from __init___parts.RadioButtonRenderer import RadioButtonRenderer
from __init___parts.RelatedImageListAttribute import RelatedImageListAttribute
from __init___parts.RetrieveVirtualItemEventArgs import RetrieveVirtualItemEventArgs
from __init___parts.RetrieveVirtualItemEventHandler import RetrieveVirtualItemEventHandler
from __init___parts.RichTextBox import RichTextBox
from __init___parts.RichTextBoxFinds import RichTextBoxFinds
from __init___parts.RichTextBoxLanguageOptions import RichTextBoxLanguageOptions
from __init___parts.RichTextBoxScrollBars import RichTextBoxScrollBars
from __init___parts.RichTextBoxSelectionAttribute import RichTextBoxSelectionAttribute
from __init___parts.RichTextBoxSelectionTypes import RichTextBoxSelectionTypes
from __init___parts.RichTextBoxStreamType import RichTextBoxStreamType
from __init___parts.RichTextBoxWordPunctuations import RichTextBoxWordPunctuations
from __init___parts.RightToLeft import RightToLeft
from __init___parts.RowStyle import RowStyle
from __init___parts.SaveFileDialog import SaveFileDialog
from __init___parts.Screen import Screen
from __init___parts.ScreenOrientation import ScreenOrientation
from __init___parts.ScrollBarRenderer import ScrollBarRenderer
from __init___parts.ScrollBars import ScrollBars
from __init___parts.ScrollButton import ScrollButton
from __init___parts.ScrollEventArgs import ScrollEventArgs
from __init___parts.ScrollEventHandler import ScrollEventHandler
from __init___parts.ScrollEventType import ScrollEventType
from __init___parts.ScrollOrientation import ScrollOrientation
from __init___parts.SearchDirectionHint import SearchDirectionHint
from __init___parts.SearchForVirtualItemEventArgs import SearchForVirtualItemEventArgs
from __init___parts.SearchForVirtualItemEventHandler import SearchForVirtualItemEventHandler
from __init___parts.SecurityIDType import SecurityIDType
from __init___parts.SelectedGridItemChangedEventArgs import SelectedGridItemChangedEventArgs
from __init___parts.SelectedGridItemChangedEventHandler import SelectedGridItemChangedEventHandler
from __init___parts.SelectionMode import SelectionMode
from __init___parts.SelectionRange import SelectionRange
from __init___parts.SelectionRangeConverter import SelectionRangeConverter
from __init___parts.SendKeys import SendKeys
from __init___parts.Shortcut import Shortcut
from __init___parts.SizeGripStyle import SizeGripStyle
from __init___parts.SizeType import SizeType
from __init___parts.SortOrder import SortOrder
from __init___parts.SplitContainer import SplitContainer
from __init___parts.Splitter import Splitter
from __init___parts.SplitterCancelEventArgs import SplitterCancelEventArgs
from __init___parts.SplitterCancelEventHandler import SplitterCancelEventHandler
from __init___parts.SplitterEventArgs import SplitterEventArgs
from __init___parts.SplitterEventHandler import SplitterEventHandler
from __init___parts.SplitterPanel import SplitterPanel
from __init___parts.StatusBar import StatusBar
from __init___parts.StatusBarDrawItemEventArgs import StatusBarDrawItemEventArgs
from __init___parts.StatusBarDrawItemEventHandler import StatusBarDrawItemEventHandler
from __init___parts.StatusBarPanel import StatusBarPanel
from __init___parts.StatusBarPanelAutoSize import StatusBarPanelAutoSize
from __init___parts.StatusBarPanelBorderStyle import StatusBarPanelBorderStyle
from __init___parts.StatusBarPanelClickEventArgs import StatusBarPanelClickEventArgs
from __init___parts.StatusBarPanelClickEventHandler import StatusBarPanelClickEventHandler
from __init___parts.StatusBarPanelStyle import StatusBarPanelStyle
from __init___parts.StatusStrip import StatusStrip
from __init___parts.StructFormat import StructFormat
from __init___parts.SystemInformation import SystemInformation
from __init___parts.SystemParameter import SystemParameter
from __init___parts.TabAlignment import TabAlignment
from __init___parts.TabAppearance import TabAppearance
from __init___parts.TabControl import TabControl
from __init___parts.TabControlAction import TabControlAction
from __init___parts.TabControlCancelEventArgs import TabControlCancelEventArgs
from __init___parts.TabControlCancelEventHandler import TabControlCancelEventHandler
from __init___parts.TabControlEventArgs import TabControlEventArgs
from __init___parts.TabControlEventHandler import TabControlEventHandler
from __init___parts.TabDrawMode import TabDrawMode
from __init___parts.TableLayoutCellPaintEventArgs import TableLayoutCellPaintEventArgs
from __init___parts.TableLayoutCellPaintEventHandler import TableLayoutCellPaintEventHandler
from __init___parts.TableLayoutStyleCollection import TableLayoutStyleCollection
from __init___parts.TableLayoutColumnStyleCollection import TableLayoutColumnStyleCollection
from __init___parts.TableLayoutControlCollection import TableLayoutControlCollection
from __init___parts.TableLayoutPanel import TableLayoutPanel
from __init___parts.TableLayoutPanelCellBorderStyle import TableLayoutPanelCellBorderStyle
from __init___parts.TableLayoutPanelCellPosition import TableLayoutPanelCellPosition
from __init___parts.TableLayoutPanelGrowStyle import TableLayoutPanelGrowStyle
from __init___parts.TableLayoutRowStyleCollection import TableLayoutRowStyleCollection
from __init___parts.TableLayoutSettings import TableLayoutSettings
from __init___parts.TabPage import TabPage
from __init___parts.TabRenderer import TabRenderer
from __init___parts.TabSizeMode import TabSizeMode
from __init___parts.TextBoxRenderer import TextBoxRenderer
from __init___parts.TextDataFormat import TextDataFormat
from __init___parts.TextFormatFlags import TextFormatFlags
from __init___parts.TextImageRelation import TextImageRelation
from __init___parts.TextRenderer import TextRenderer
from __init___parts.ThreadExceptionDialog import ThreadExceptionDialog
from __init___parts.TickStyle import TickStyle
from __init___parts.Timer import Timer
from __init___parts.ToolBar import ToolBar
from __init___parts.ToolBarAppearance import ToolBarAppearance
from __init___parts.ToolBarButton import ToolBarButton
from __init___parts.ToolBarButtonClickEventArgs import ToolBarButtonClickEventArgs
from __init___parts.ToolBarButtonClickEventHandler import ToolBarButtonClickEventHandler
from __init___parts.ToolBarButtonStyle import ToolBarButtonStyle
from __init___parts.ToolBarTextAlign import ToolBarTextAlign
from __init___parts.ToolStripArrowRenderEventArgs import ToolStripArrowRenderEventArgs
from __init___parts.ToolStripArrowRenderEventHandler import ToolStripArrowRenderEventHandler
from __init___parts.ToolStripItem import ToolStripItem
from __init___parts.ToolStripButton import ToolStripButton
from __init___parts.ToolStripControlHost import ToolStripControlHost
from __init___parts.ToolStripComboBox import ToolStripComboBox
from __init___parts.ToolStripContainer import ToolStripContainer
from __init___parts.ToolStripContentPanel import ToolStripContentPanel
from __init___parts.ToolStripContentPanelRenderEventArgs import ToolStripContentPanelRenderEventArgs
from __init___parts.ToolStripContentPanelRenderEventHandler import ToolStripContentPanelRenderEventHandler
from __init___parts.ToolStripDropDownItem import ToolStripDropDownItem
from __init___parts.ToolStripDropDownButton import ToolStripDropDownButton
from __init___parts.ToolStripDropDownClosedEventArgs import ToolStripDropDownClosedEventArgs
from __init___parts.ToolStripDropDownClosedEventHandler import ToolStripDropDownClosedEventHandler
from __init___parts.ToolStripDropDownCloseReason import ToolStripDropDownCloseReason
from __init___parts.ToolStripDropDownClosingEventArgs import ToolStripDropDownClosingEventArgs
from __init___parts.ToolStripDropDownClosingEventHandler import ToolStripDropDownClosingEventHandler
from __init___parts.ToolStripDropDownDirection import ToolStripDropDownDirection
from __init___parts.ToolStripDropDownItemAccessibleObject import ToolStripDropDownItemAccessibleObject
from __init___parts.ToolStripGripDisplayStyle import ToolStripGripDisplayStyle
from __init___parts.ToolStripRenderEventArgs import ToolStripRenderEventArgs
from __init___parts.ToolStripGripRenderEventArgs import ToolStripGripRenderEventArgs
from __init___parts.ToolStripGripRenderEventHandler import ToolStripGripRenderEventHandler
from __init___parts.ToolStripGripStyle import ToolStripGripStyle
from __init___parts.ToolStripItemAlignment import ToolStripItemAlignment
from __init___parts.ToolStripItemClickedEventArgs import ToolStripItemClickedEventArgs
from __init___parts.ToolStripItemClickedEventHandler import ToolStripItemClickedEventHandler
from __init___parts.ToolStripItemCollection import ToolStripItemCollection
from __init___parts.ToolStripItemDisplayStyle import ToolStripItemDisplayStyle
from __init___parts.ToolStripItemEventArgs import ToolStripItemEventArgs
from __init___parts.ToolStripItemEventHandler import ToolStripItemEventHandler
from __init___parts.ToolStripItemRenderEventArgs import ToolStripItemRenderEventArgs
from __init___parts.ToolStripItemImageRenderEventArgs import ToolStripItemImageRenderEventArgs
from __init___parts.ToolStripItemImageRenderEventHandler import ToolStripItemImageRenderEventHandler
from __init___parts.ToolStripItemImageScaling import ToolStripItemImageScaling
from __init___parts.ToolStripItemOverflow import ToolStripItemOverflow
from __init___parts.ToolStripItemPlacement import ToolStripItemPlacement
from __init___parts.ToolStripItemRenderEventHandler import ToolStripItemRenderEventHandler
from __init___parts.ToolStripItemTextRenderEventArgs import ToolStripItemTextRenderEventArgs
from __init___parts.ToolStripItemTextRenderEventHandler import ToolStripItemTextRenderEventHandler
from __init___parts.ToolStripLabel import ToolStripLabel
from __init___parts.ToolStripLayoutStyle import ToolStripLayoutStyle
from __init___parts.ToolStripManager import ToolStripManager
from __init___parts.ToolStripManagerRenderMode import ToolStripManagerRenderMode
from __init___parts.ToolStripMenuItem import ToolStripMenuItem
from __init___parts.ToolStripOverflow import ToolStripOverflow
from __init___parts.ToolStripOverflowButton import ToolStripOverflowButton
from __init___parts.ToolStripPanel import ToolStripPanel
from __init___parts.ToolStripPanelRenderEventArgs import ToolStripPanelRenderEventArgs
from __init___parts.ToolStripPanelRenderEventHandler import ToolStripPanelRenderEventHandler
from __init___parts.ToolStripPanelRow import ToolStripPanelRow
from __init___parts.ToolStripRenderer import ToolStripRenderer
from __init___parts.ToolStripProfessionalRenderer import ToolStripProfessionalRenderer
from __init___parts.ToolStripProgressBar import ToolStripProgressBar
from __init___parts.ToolStripRenderEventHandler import ToolStripRenderEventHandler
from __init___parts.ToolStripRenderMode import ToolStripRenderMode
from __init___parts.ToolStripSeparator import ToolStripSeparator
from __init___parts.ToolStripSeparatorRenderEventArgs import ToolStripSeparatorRenderEventArgs
from __init___parts.ToolStripSeparatorRenderEventHandler import ToolStripSeparatorRenderEventHandler
from __init___parts.ToolStripSplitButton import ToolStripSplitButton
from __init___parts.ToolStripStatusLabel import ToolStripStatusLabel
from __init___parts.ToolStripStatusLabelBorderSides import ToolStripStatusLabelBorderSides
from __init___parts.ToolStripSystemRenderer import ToolStripSystemRenderer
from __init___parts.ToolStripTextBox import ToolStripTextBox
from __init___parts.ToolStripTextDirection import ToolStripTextDirection
from __init___parts.ToolTip import ToolTip
from __init___parts.ToolTipIcon import ToolTipIcon
from __init___parts.TrackBar import TrackBar
from __init___parts.TrackBarRenderer import TrackBarRenderer
from __init___parts.TreeNode import TreeNode
from __init___parts.TreeNodeCollection import TreeNodeCollection
from __init___parts.TreeNodeConverter import TreeNodeConverter
from __init___parts.TreeNodeMouseClickEventArgs import TreeNodeMouseClickEventArgs
from __init___parts.TreeNodeMouseClickEventHandler import TreeNodeMouseClickEventHandler
from __init___parts.TreeNodeMouseHoverEventArgs import TreeNodeMouseHoverEventArgs
from __init___parts.TreeNodeMouseHoverEventHandler import TreeNodeMouseHoverEventHandler
from __init___parts.TreeNodeStates import TreeNodeStates
from __init___parts.TreeView import TreeView
from __init___parts.TreeViewAction import TreeViewAction
from __init___parts.TreeViewCancelEventArgs import TreeViewCancelEventArgs
from __init___parts.TreeViewCancelEventHandler import TreeViewCancelEventHandler
from __init___parts.TreeViewDrawMode import TreeViewDrawMode
from __init___parts.TreeViewEventArgs import TreeViewEventArgs
from __init___parts.TreeViewEventHandler import TreeViewEventHandler
from __init___parts.TreeViewHitTestInfo import TreeViewHitTestInfo
from __init___parts.TreeViewHitTestLocations import TreeViewHitTestLocations
from __init___parts.TreeViewImageIndexConverter import TreeViewImageIndexConverter
from __init___parts.TreeViewImageKeyConverter import TreeViewImageKeyConverter
from __init___parts.TypeValidationEventArgs import TypeValidationEventArgs
from __init___parts.TypeValidationEventHandler import TypeValidationEventHandler
from __init___parts.UICues import UICues
from __init___parts.UICuesEventArgs import UICuesEventArgs
from __init___parts.UICuesEventHandler import UICuesEventHandler
from __init___parts.UnhandledExceptionMode import UnhandledExceptionMode
from __init___parts.UpDownEventArgs import UpDownEventArgs
from __init___parts.UpDownEventHandler import UpDownEventHandler
from __init___parts.UserControl import UserControl
from __init___parts.ValidationConstraints import ValidationConstraints
from __init___parts.View import View
from __init___parts.VScrollBar import VScrollBar
from __init___parts.VScrollProperties import VScrollProperties
from __init___parts.WebBrowserBase import WebBrowserBase
from __init___parts.WebBrowser import WebBrowser
from __init___parts.WebBrowserDocumentCompletedEventArgs import WebBrowserDocumentCompletedEventArgs
from __init___parts.WebBrowserDocumentCompletedEventHandler import WebBrowserDocumentCompletedEventHandler
from __init___parts.WebBrowserEncryptionLevel import WebBrowserEncryptionLevel
from __init___parts.WebBrowserNavigatedEventArgs import WebBrowserNavigatedEventArgs
from __init___parts.WebBrowserNavigatedEventHandler import WebBrowserNavigatedEventHandler
from __init___parts.WebBrowserNavigatingEventArgs import WebBrowserNavigatingEventArgs
from __init___parts.WebBrowserNavigatingEventHandler import WebBrowserNavigatingEventHandler
from __init___parts.WebBrowserProgressChangedEventArgs import WebBrowserProgressChangedEventArgs
from __init___parts.WebBrowserProgressChangedEventHandler import WebBrowserProgressChangedEventHandler
from __init___parts.WebBrowserReadyState import WebBrowserReadyState
from __init___parts.WebBrowserRefreshOption import WebBrowserRefreshOption
from __init___parts.WebBrowserSiteBase import WebBrowserSiteBase
from __init___parts.WindowsFormsSection import WindowsFormsSection
from __init___parts.WindowsFormsSynchronizationContext import WindowsFormsSynchronizationContext



class BindingContext(object,ICollection,IEnumerable):
 """
 Manages the collection of System.Windows.Forms.BindingManagerBase objects for any object that inherits from the System.Windows.Forms.Control class.

 

 BindingContext()
 """
 def Add(self,*args):
  """
  Add(self: BindingContext,dataSource: object,listManager: BindingManagerBase)

   Adds the System.Windows.Forms.BindingManagerBase associated with a specific data source to the 

    collection.

  

  

   dataSource: The System.Object associated with the System.Windows.Forms.BindingManagerBase.

   listManager: The System.Windows.Forms.BindingManagerBase to add.
  """
  pass
 def AddCore(self,*args):
  """
  AddCore(self: BindingContext,dataSource: object,listManager: BindingManagerBase)

   Adds the System.Windows.Forms.BindingManagerBase associated with a specific data source to the 

    collection.

  

  

   dataSource: The object associated with the System.Windows.Forms.BindingManagerBase.

   listManager: The System.Windows.Forms.BindingManagerBase to add.
  """
  pass
 def Clear(self,*args):
  """
  Clear(self: BindingContext)

   Clears the collection of any System.Windows.Forms.BindingManagerBase objects.
  """
  pass
 def ClearCore(self,*args):
  """
  ClearCore(self: BindingContext)

   Clears the collection.
  """
  pass
 def Contains(self,dataSource,dataMember=None):
  """
  Contains(self: BindingContext,dataSource: object,dataMember: str) -> bool

  

   Gets a value indicating whether the System.Windows.Forms.BindingContext contains the 

    System.Windows.Forms.BindingManagerBase associated with the specified data source and data 

    member.

  

  

   dataSource: An System.Object that represents the data source.

   dataMember: The information needed to resolve to a specific System.Windows.Forms.BindingManagerBase.

   Returns: true if the System.Windows.Forms.BindingContext contains the specified 

    System.Windows.Forms.BindingManagerBase; otherwise,false.

  

  Contains(self: BindingContext,dataSource: object) -> bool

  

   Gets a value indicating whether the System.Windows.Forms.BindingContext contains the 

    System.Windows.Forms.BindingManagerBase associated with the specified data source.

  

  

   dataSource: An System.Object that represents the data source.

   Returns: true if the System.Windows.Forms.BindingContext contains the specified 

    System.Windows.Forms.BindingManagerBase; otherwise,false.
  """
  pass
 def OnCollectionChanged(self,*args):
  """
  OnCollectionChanged(self: BindingContext,ccevent: CollectionChangeEventArgs)

   Raises the System.Windows.Forms.BindingContext.CollectionChanged event.

  

   ccevent: A System.ComponentModel.CollectionChangeEventArgs that contains the event data.
  """
  pass
 def Remove(self,*args):
  """
  Remove(self: BindingContext,dataSource: object)

   Deletes the System.Windows.Forms.BindingManagerBase associated with the specified data source.

  

   dataSource: The data source associated with the System.Windows.Forms.BindingManagerBase to remove.
  """
  pass
 def RemoveCore(self,*args):
  """
  RemoveCore(self: BindingContext,dataSource: object)

   Removes the System.Windows.Forms.BindingManagerBase associated with the specified data source.

  

   dataSource: The data source associated with the System.Windows.Forms.BindingManagerBase to remove.
  """
  pass
 @staticmethod
 def UpdateBinding(newBindingContext,binding):
  """
  UpdateBinding(newBindingContext: BindingContext,binding: Binding)

   Associates a System.Windows.Forms.Binding with a new System.Windows.Forms.BindingContext.

  

   newBindingContext: The new System.Windows.Forms.BindingContext to associate with the System.Windows.Forms.Binding.

   binding: The System.Windows.Forms.Binding to associate with the new System.Windows.Forms.BindingContext.
  """
  pass
 def __getitem__(self,*args):
  """ x.__getitem__(y) <==> x[y]x.__getitem__(y) <==> x[y] """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __iter__(self,*args):
  """ __iter__(self: IEnumerable) -> object """
  pass
 def __len__(self,*args):
  """ x.__len__() <==> len(x) """
  pass
 def __repr__(self,*args):
  """ __repr__(self: object) -> str """
  pass
 IsReadOnly=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a value indicating whether the collection is read-only.



Get: IsReadOnly(self: BindingContext) -> bool



"""


 CollectionChanged=None




class FUNCFLAGS(Enum,IComparable,IFormattable,IConvertible):
 """
 Use System.Runtime.InteropServices.ComTypes.FUNCFLAGS instead.

 

 enum (flags) FUNCFLAGS,values: FUNCFLAG_FBINDABLE (4),FUNCFLAG_FDEFAULTBIND (32),FUNCFLAG_FDEFAULTCOLLELEM (256),FUNCFLAG_FDISPLAYBIND (16),FUNCFLAG_FHIDDEN (64),FUNCFLAG_FIMMEDIATEBIND (4096),FUNCFLAG_FNONBROWSABLE (1024),FUNCFLAG_FREPLACEABLE (2048),FUNCFLAG_FREQUESTEDIT (8),FUNCFLAG_FRESTRICTED (1),FUNCFLAG_FSOURCE (2),FUNCFLAG_FUIDEFAULT (512),FUNCFLAG_FUSESGETLASTERROR (128)
 """
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==yx.__eq__(y) <==> x==yx.__eq__(y) <==> x==y """
  pass
 def __format__(self,*args):
  """ __format__(formattable: IFormattable,format: str) -> str """
  pass
 def __ge__(self,*args):
  pass
 def __gt__(self,*args):
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __le__(self,*args):
  pass
 def __lt__(self,*args):
  pass
 def __ne__(self,*args):
  pass
 def __reduce_ex__(self,*args):
  pass
 def __str__(self,*args):
  pass
 FUNCFLAG_FBINDABLE=None
 FUNCFLAG_FDEFAULTBIND=None
 FUNCFLAG_FDEFAULTCOLLELEM=None
 FUNCFLAG_FDISPLAYBIND=None
 FUNCFLAG_FHIDDEN=None
 FUNCFLAG_FIMMEDIATEBIND=None
 FUNCFLAG_FNONBROWSABLE=None
 FUNCFLAG_FREPLACEABLE=None
 FUNCFLAG_FREQUESTEDIT=None
 FUNCFLAG_FRESTRICTED=None
 FUNCFLAG_FSOURCE=None
 FUNCFLAG_FUIDEFAULT=None
 FUNCFLAG_FUSESGETLASTERROR=None
 value__=None




class ToolTip(Component,IComponent,IDisposable,IExtenderProvider):
 """
 Represents a small rectangular pop-up window that displays a brief description of a control's purpose when the user rests the pointer on the control.

 

 ToolTip(cont: IContainer)

 ToolTip()
 """
 def CanExtend(self,target):
  """
  CanExtend(self: ToolTip,target: object) -> bool

  

   Returns true if the ToolTip can offer an extender property to the specified target component.

  

   target: The target object to add an extender property to.

   Returns: true if the System.Windows.Forms.ToolTip class can offer one or more extender properties; 

    otherwise,false.
  """
  pass
 def Dispose(self):
  """
  Dispose(self: ToolTip,disposing: bool)

   Disposes of the System.Windows.Forms.ToolTip component.

  

   disposing: true to release both managed and unmanaged resources; false to release only unmanaged resources.
  """
  pass
 def GetService(self,*args):
  """
  GetService(self: Component,service: Type) -> object

  

   Returns an object that represents a service provided by the System.ComponentModel.Component or 

    by its System.ComponentModel.Container.

  

  

   service: A service provided by the System.ComponentModel.Component.

   Returns: An System.Object that represents a service provided by the System.ComponentModel.Component,or 

    null if the System.ComponentModel.Component does not provide the specified service.
  """
  pass
 def GetToolTip(self,control):
  """
  GetToolTip(self: ToolTip,control: Control) -> str

  

   Retrieves the ToolTip text associated with the specified control.

  

   control: The System.Windows.Forms.Control for which to retrieve the System.Windows.Forms.ToolTip text.

   Returns: A System.String containing the ToolTip text for the specified control.
  """
  pass
 def Hide(self,win):
  """
  Hide(self: ToolTip,win: IWin32Window)

   Hides the specified ToolTip window.

  

   win: The System.Windows.Forms.IWin32Window of the associated window or control that the ToolTip is 

    associated with.
  """
  pass
 def MemberwiseClone(self,*args):
  """
  MemberwiseClone(self: MarshalByRefObject,cloneIdentity: bool) -> MarshalByRefObject

  

   Creates a shallow copy of the current System.MarshalByRefObject object.

  

   cloneIdentity: false to delete the current System.MarshalByRefObject object's identity,which will cause the 

    object to be assigned a new identity when it is marshaled across a remoting boundary. A value of 

    false is usually appropriate. true to copy the current System.MarshalByRefObject object's 

    identity to its clone,which will cause remoting client calls to be routed to the remote server 

    object.

  

   Returns: A shallow copy of the current System.MarshalByRefObject object.

  MemberwiseClone(self: object) -> object

  

   Creates a shallow copy of the current System.Object.

   Returns: A shallow copy of the current System.Object.
  """
  pass
 def RemoveAll(self):
  """
  RemoveAll(self: ToolTip)

   Removes all ToolTip text currently associated with the ToolTip component.
  """
  pass
 def SetToolTip(self,control,caption):
  """
  SetToolTip(self: ToolTip,control: Control,caption: str)

   Associates ToolTip text with the specified control.

  

   control: The System.Windows.Forms.Control to associate the ToolTip text with.

   caption: The ToolTip text to display when the pointer is on the control.
  """
  pass
 def Show(self,text,window,*__args):
  """
  Show(self: ToolTip,text: str,window: IWin32Window,point: Point,duration: int)

   Sets the ToolTip text associated with the specified control,and then displays the ToolTip for 

    the specified duration at the specified relative position.

  

  

   text: A System.String containing the new ToolTip text.

   window: The System.Windows.Forms.Control to display the ToolTip for.

   point: A System.Drawing.Point containing the offset,in pixels,relative to the upper-left corner of 

    the associated control window,to display the ToolTip.

  

   duration: An System.Int32 containing the duration,in milliseconds,to display the ToolTip.

  Show(self: ToolTip,text: str,window: IWin32Window,x: int,y: int)

   Sets the ToolTip text associated with the specified control,and then displays the ToolTip 

    modally at the specified relative position.

  

  

   text: A System.String containing the new ToolTip text.

   window: The System.Windows.Forms.Control to display the ToolTip for.

   x: The horizontal offset,in pixels,relative to the upper-left corner of the associated control 

    window,to display the ToolTip.

  

   y: The vertical offset,in pixels,relative to the upper-left corner of the associated control 

    window,to display the ToolTip.

  

  Show(self: ToolTip,text: str,window: IWin32Window,x: int,y: int,duration: int)

   Sets the ToolTip text associated with the specified control,and then displays the ToolTip for 

    the specified duration at the specified relative position.

  

  

   text: A System.String containing the new ToolTip text.

   window: The System.Windows.Forms.Control to display the ToolTip for.

   x: The horizontal offset,in pixels,relative to the upper-left corner of the associated control 

    window,to display the ToolTip.

  

   y: The vertical offset,in pixels,relative to the upper-left corner of the associated control 

    window,to display the ToolTip.

  

   duration: An System.Int32 containing the duration,in milliseconds,to display the ToolTip.

  Show(self: ToolTip,text: str,window: IWin32Window)

   Sets the ToolTip text associated with the specified control,and displays the ToolTip modally.

  

   text: A System.String containing the new ToolTip text.

   window: The System.Windows.Forms.Control to display the ToolTip for.

  Show(self: ToolTip,text: str,window: IWin32Window,duration: int)

   Sets the ToolTip text associated with the specified control,and then displays the ToolTip for 

    the specified duration.

  

  

   text: A System.String containing the new ToolTip text.

   window: The System.Windows.Forms.Control to display the ToolTip for.

   duration: An System.Int32 containing the duration,in milliseconds,to display the ToolTip.

  Show(self: ToolTip,text: str,window: IWin32Window,point: Point)

   Sets the ToolTip text associated with the specified control,and then displays the ToolTip 

    modally at the specified relative position.

  

  

   text: A System.String containing the new ToolTip text.

   window: The System.Windows.Forms.Control to display the ToolTip for.

   point: A System.Drawing.Point containing the offset,in pixels,relative to the upper-left corner of 

    the associated control window,to display the ToolTip.
  """
  pass
 def StopTimer(self,*args):
  """
  StopTimer(self: ToolTip)

   Stops the timer that hides displayed ToolTips.
  """
  pass
 def ToString(self):
  """
  ToString(self: ToolTip) -> str

  

   Returns a string representation for this control.

   Returns: A System.String containing a description of the System.Windows.Forms.ToolTip.
  """
  pass
 def __enter__(self,*args):
  """
  __enter__(self: IDisposable) -> object

  

   Provides the implementation of __enter__ for objects which implement IDisposable.
  """
  pass
 def __exit__(self,*args):
  """
  __exit__(self: IDisposable,exc_type: object,exc_value: object,exc_back: object)

   Provides the implementation of __exit__ for objects which implement IDisposable.
  """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 @staticmethod
 def __new__(self,cont=None):
  """
  __new__(cls: type,cont: IContainer)

  __new__(cls: type)
  """
  pass
 def __str__(self,*args):
  pass
 Active=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets a value indicating whether the ToolTip is currently active.



Get: Active(self: ToolTip) -> bool



Set: Active(self: ToolTip)=value

"""

 AutomaticDelay=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the automatic delay for the ToolTip.



Get: AutomaticDelay(self: ToolTip) -> int



Set: AutomaticDelay(self: ToolTip)=value

"""

 AutoPopDelay=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the period of time the ToolTip remains visible if the pointer is stationary on a control with specified ToolTip text.



Get: AutoPopDelay(self: ToolTip) -> int



Set: AutoPopDelay(self: ToolTip)=value

"""

 BackColor=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the background color for the ToolTip.



Get: BackColor(self: ToolTip) -> Color



Set: BackColor(self: ToolTip)=value

"""

 CanRaiseEvents=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a value indicating whether the component can raise an event.



"""

 CreateParams=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the creation parameters for the ToolTip window.



"""

 DesignMode=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a value that indicates whether the System.ComponentModel.Component is currently in design mode.



"""

 Events=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the list of event handlers that are attached to this System.ComponentModel.Component.



"""

 ForeColor=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the foreground color for the ToolTip.



Get: ForeColor(self: ToolTip) -> Color



Set: ForeColor(self: ToolTip)=value

"""

 InitialDelay=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the time that passes before the ToolTip appears.



Get: InitialDelay(self: ToolTip) -> int



Set: InitialDelay(self: ToolTip)=value

"""

 IsBalloon=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets a value indicating whether the ToolTip should use a balloon window.



Get: IsBalloon(self: ToolTip) -> bool



Set: IsBalloon(self: ToolTip)=value

"""

 OwnerDraw=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets a value indicating whether the ToolTip is drawn by the operating system or by code that you provide.



Get: OwnerDraw(self: ToolTip) -> bool



Set: OwnerDraw(self: ToolTip)=value

"""

 ReshowDelay=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the length of time that must transpire before subsequent ToolTip windows appear as the pointer moves from one control to another.



Get: ReshowDelay(self: ToolTip) -> int



Set: ReshowDelay(self: ToolTip)=value

"""

 ShowAlways=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets a value indicating whether a ToolTip window is displayed,even when its parent control is not active.



Get: ShowAlways(self: ToolTip) -> bool



Set: ShowAlways(self: ToolTip)=value

"""

 StripAmpersands=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets a value that determines how ampersand (&) characters are treated.



Get: StripAmpersands(self: ToolTip) -> bool



Set: StripAmpersands(self: ToolTip)=value

"""

 Tag=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the object that contains programmer-supplied data associated with the System.Windows.Forms.ToolTip.



Get: Tag(self: ToolTip) -> object



Set: Tag(self: ToolTip)=value

"""

 ToolTipIcon=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets a value that defines the type of icon to be displayed alongside the ToolTip text.



Get: ToolTipIcon(self: ToolTip) -> ToolTipIcon



Set: ToolTipIcon(self: ToolTip)=value

"""

 ToolTipTitle=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets a title for the ToolTip window.



Get: ToolTipTitle(self: ToolTip) -> str



Set: ToolTipTitle(self: ToolTip)=value

"""

 UseAnimation=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets a value determining whether an animation effect should be used when displaying the ToolTip.



Get: UseAnimation(self: ToolTip) -> bool



Set: UseAnimation(self: ToolTip)=value

"""

 UseFading=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets a value determining whether a fade effect should be used when displaying the ToolTip.



Get: UseFading(self: ToolTip) -> bool



Set: UseFading(self: ToolTip)=value

"""


 Draw=None
 Popup=None




class InkCanvasSelectionHitResult(Enum,IComparable,IFormattable,IConvertible):
 """
 Identifies the various parts of a selection adorner on an System.Windows.Controls.InkCanvas.

 

 enum InkCanvasSelectionHitResult,values: Bottom (6),BottomLeft (7),BottomRight (5),Left (8),None (0),Right (4),Selection (9),Top (2),TopLeft (1),TopRight (3)
 """
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==yx.__eq__(y) <==> x==yx.__eq__(y) <==> x==y """
  pass
 def __format__(self,*args):
  """ __format__(formattable: IFormattable,format: str) -> str """
  pass
 def __ge__(self,*args):
  pass
 def __gt__(self,*args):
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __le__(self,*args):
  pass
 def __lt__(self,*args):
  pass
 def __ne__(self,*args):
  pass
 def __reduce_ex__(self,*args):
  pass
 def __str__(self,*args):
  pass
 Bottom=None
 BottomLeft=None
 BottomRight=None
 Left=None
 None=None
 Right=None
 Selection=None
 Top=None
 TopLeft=None
 TopRight=None
 value__=None




class WebResponse(MarshalByRefObject,ISerializable,IDisposable):
 """ Provides a response from a Uniform Resource Identifier (URI). This is an abstract class. """
 def Close(self):
  """
  Close(self: WebResponse)

   When overridden by a descendant class,closes the response stream.
  """
  pass
 def Dispose(self):
  """ Dispose(self: WebResponse) """
  pass
 def GetObjectData(self,*args):
  """
  GetObjectData(self: WebResponse,serializationInfo: SerializationInfo,streamingContext: StreamingContext)

   Populates a System.Runtime.Serialization.SerializationInfo with the data that is needed to 

    serialize the target object.

  

  

   serializationInfo: The System.Runtime.Serialization.SerializationInfo to populate with data.

   streamingContext: A System.Runtime.Serialization.StreamingContext that specifies the destination for this 

    serialization.
  """
  pass
 def GetResponseStream(self):
  """
  GetResponseStream(self: WebResponse) -> Stream

  

   When overridden in a descendant class,returns the data stream from the Internet resource.

   Returns: An instance of the System.IO.Stream class for reading data from the Internet resource.
  """
  pass
 def MemberwiseClone(self,*args):
  """
  MemberwiseClone(self: MarshalByRefObject,cloneIdentity: bool) -> MarshalByRefObject

  

   Creates a shallow copy of the current System.MarshalByRefObject object.

  

   cloneIdentity: false to delete the current System.MarshalByRefObject object's identity,which will cause the 

    object to be assigned a new identity when it is marshaled across a remoting boundary. A value of 

    false is usually appropriate. true to copy the current System.MarshalByRefObject object's 

    identity to its clone,which will cause remoting client calls to be routed to the remote server 

    object.

  

   Returns: A shallow copy of the current System.MarshalByRefObject object.

  MemberwiseClone(self: object) -> object

  

   Creates a shallow copy of the current System.Object.

   Returns: A shallow copy of the current System.Object.
  """
  pass
 def __enter__(self,*args):
  """
  __enter__(self: IDisposable) -> object

  

   Provides the implementation of __enter__ for objects which implement IDisposable.
  """
  pass
 def __exit__(self,*args):
  """
  __exit__(self: IDisposable,exc_type: object,exc_value: object,exc_back: object)

   Provides the implementation of __exit__ for objects which implement IDisposable.
  """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 @staticmethod
 def __new__(self,*args): #cannot find CLR constructor
  """
  __new__(cls: type)

  __new__(cls: type,serializationInfo: SerializationInfo,streamingContext: StreamingContext)
  """
  pass
 def __reduce_ex__(self,*args):
  pass
 ContentLength=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """When overridden in a descendant class,gets or sets the content length of data being received.



Get: ContentLength(self: WebResponse) -> Int64



Set: ContentLength(self: WebResponse)=value

"""

 ContentType=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """When overridden in a derived class,gets or sets the content type of the data being received.



Get: ContentType(self: WebResponse) -> str



Set: ContentType(self: WebResponse)=value

"""

 Headers=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """When overridden in a derived class,gets a collection of header name-value pairs associated with this request.



Get: Headers(self: WebResponse) -> WebHeaderCollection



"""

 IsFromCache=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a System.Boolean value that indicates whether this response was obtained from the cache.



Get: IsFromCache(self: WebResponse) -> bool



"""

 IsMutuallyAuthenticated=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a System.Boolean value that indicates whether mutual authentication occurred.



Get: IsMutuallyAuthenticated(self: WebResponse) -> bool



"""

 ResponseUri=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """When overridden in a derived class,gets the URI of the Internet resource that actually responded to the request.



Get: ResponseUri(self: WebResponse) -> Uri



"""

 SupportsHeaders=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Get: SupportsHeaders(self: WebResponse) -> bool



"""





class IContainer(IDisposable):
 """ Provides functionality for containers. Containers are objects that logically contain zero or more components. """
 def Add(self,component,name=None):
  """
  Add(self: IContainer,component: IComponent,name: str)

   Adds the specified System.ComponentModel.IComponent to the System.ComponentModel.IContainer at 

    the end of the list,and assigns a name to the component.

  

  

   component: The System.ComponentModel.IComponent to add.

   name: The unique,case-insensitive name to assign to the component.-or- null that leaves the component 

    unnamed.

  

  Add(self: IContainer,component: IComponent)

   Adds the specified System.ComponentModel.IComponent to the System.ComponentModel.IContainer at 

    the end of the list.

  

  

   component: The System.ComponentModel.IComponent to add.
  """
  pass
 def Remove(self,component):
  """
  Remove(self: IContainer,component: IComponent)

   Removes a component from the System.ComponentModel.IContainer.

  

   component: The System.ComponentModel.IComponent to remove.
  """
  pass
 def __add__(self,*args):
  """ x.__add__(y) <==> x+yx.__add__(y) <==> x+y """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 Components=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets all the components in the System.ComponentModel.IContainer.



Get: Components(self: IContainer) -> ComponentCollection



"""





class HtmlWindow(object):
 """ Represents the logical window that contains one or more instances of System.Windows.Forms.HtmlDocument. """
 def Alert(self,message):
  """
  Alert(self: HtmlWindow,message: str)

   Displays a message box.

  

   message: The System.String to display in the message box.
  """
  pass
 def AttachEventHandler(self,eventName,eventHandler):
  """
  AttachEventHandler(self: HtmlWindow,eventName: str,eventHandler: EventHandler)

   Adds an event handler for the named HTML DOM event.

  

   eventName: The name of the event you want to handle.

   eventHandler: A reference to the managed code that handles the event.
  """
  pass
 def Close(self):
  """
  Close(self: HtmlWindow)

   Closes the window.
  """
  pass
 def Confirm(self,message):
  """
  Confirm(self: HtmlWindow,message: str) -> bool

  

   Displays a dialog box with a message and buttons to solicit a yes/no response.

  

   message: The text to display to the user.

   Returns: true if the user clicked Yes; false if the user clicked No or closed the dialog box.
  """
  pass
 def DetachEventHandler(self,eventName,eventHandler):
  """
  DetachEventHandler(self: HtmlWindow,eventName: str,eventHandler: EventHandler)

   Removes the named event handler.

  

   eventName: The name of the event you want to handle.

   eventHandler: A reference to the managed code that handles the event.
  """
  pass
 def Equals(self,obj):
  """
  Equals(self: HtmlWindow,obj: object) -> bool

  

   Tests the object for equality against the current object.

  

   obj: The object to test.

   Returns: true if the objects are equal; otherwise,false.
  """
  pass
 def Focus(self):
  """
  Focus(self: HtmlWindow)

   Puts the focus on the current window.
  """
  pass
 def GetHashCode(self):
  """
  GetHashCode(self: HtmlWindow) -> int

   Returns: System.Int32
  """
  pass
 def MoveTo(self,*__args):
  """
  MoveTo(self: HtmlWindow,point: Point)

   Moves the window to the specified coordinates on the screen.

  

   point: The x- and y-coordinates of the window's upper-left corner.

  MoveTo(self: HtmlWindow,x: int,y: int)

   Moves the window to the specified coordinates on the screen.

  

   x: The x-coordinate of the window's upper-left corner.

   y: The y-coordinate of the window's upper-left corner.
  """
  pass
 def Navigate(self,*__args):
  """
  Navigate(self: HtmlWindow,urlString: str)

   Displays or downloads the new content located at the specified URL.

  

   urlString: The resource to display,described by a Uniform Resource Locator.

  Navigate(self: HtmlWindow,url: Uri)

   Displays a new document in the current window.

  

   url: The location,specified as a System.Uri,of the document or object to display in the current 

    window.
  """
  pass
 def Open(self,*__args):
  """
  Open(self: HtmlWindow,url: Uri,target: str,windowOptions: str,replaceEntry: bool) -> HtmlWindow

  

   Displays a file in the named window.

  

   url: The Uniform Resource Locator that describes the location of the file to load.

   target: The name of the window in which to open the resource. This can be a developer-supplied name,or 

    one of the following special values:_blank: Opens url in a new window. Works the same as a call 

    to System.Windows.Forms.HtmlWindow.OpenNew(System.String,System.String)._media: Opens url in the 

    Media bar. _parent: Opens url in the window that created the current window._search: Opens url 

    in the Search bar._self: Opens url in the current window. _top: If called against a window 

    belonging to a FRAME element,opens url in the window hosting its FRAMESET. Otherwise,acts the 

    same as _self.

  

   windowOptions: A comma-delimited string consisting of zero or more of the following options in the form 

    name=value. Except for the left,top,height,and width options,which take arbitrary integers,

    each option accepts yes or 1,and no or 0,as valid values.channelmode: Used with the deprecated 

    channels technology of Internet Explorer 4.0. Default is no.directories: Whether the window 

    should display directory navigation buttons. Default is yes. height: The height of the window's 

    client area,in pixels. The minimum is 100; attempts to open a window smaller than this will 

    cause the window to open according to The Internet Explorer defaults. left: The left 

    (x-coordinate) position of the window,relative to the upper-left corner of the user's screen,

    in pixels. Must be a positive integer.location: Whether to display the Address bar,which 

    enables users to navigate the window to a new URL. Default is yes. menubar: Whether to display 

    menus on the new window. Default is yes.resizable: Whether the window can be resized by the 

    user. Default is yes.scrollbars: Whether the window has horizontal and vertical scroll bars. 

    Default is yes.status: Whether the window has a status bar at the bottom. Default is 

    yes.titlebar: Whether the title of the current page is displayed. Setting this option to no has 

    no effect within a managed application; the title bar will always appear.toolbar: Whether 

    toolbar buttons such as Back,Forward,and Stop are visible. Default is yes.top: The top 

    (y-coordinate) position of the window,relative to the upper-left corner of the user's screen,

    in pixels. Must be a positive integer.width: The width of the window's client area,in pixels. 

    The minimum is 100; attempts to open a window smaller than this will cause the window to open 

    according to The Internet Explorer defaults.

  

   replaceEntry: Whether url replaces the current window's URL in the navigation history. This will effect the 

    operation of methods on the System.Windows.Forms.HtmlHistory class.

  

   Returns: An System.Windows.Forms.HtmlWindow representing the new window,or the previously created window 

    named by the target parameter.

  

  Open(self: HtmlWindow,urlString: str,target: str,windowOptions: str,replaceEntry: bool) -> HtmlWindow

  

   Displays a file in the named window.

  

   urlString: The Uniform Resource Locator that describes the location of the file to load.

   target: The name of the window in which to open the resource. This may be a developer-supplied name,or 

    one of the following special values:_blank: Opens url in a new window. Works the same as a call 

    to System.Windows.Forms.HtmlWindow.OpenNew(System.String,System.String)._media: Opens url in the 

    Media bar. _parent: Opens url in the window that created the current window._search: Opens url 

    in the Search bar._self: Opens url in the current window. _top: If called against a window 

    belonging to a FRAME element,opens url in the window hosting its FRAMESET. Otherwise,acts the 

    same as _self.

  

   windowOptions: A comma-delimited string consisting of zero or more of the following options in the form 

    name=value. Except for the left,top,height,and width options,which take arbitrary integers,

    each option accepts yes or 1,and no or 0,as valid values.channelmode: Used with the deprecated 

    channels technology of Internet Explorer 4.0. Default is no.directories: Whether the window 

    should display directory navigation buttons. Default is yes. height: The height of the window's 

    client area,in pixels. The minimum is 100; attempts to open a window smaller than this will 

    cause the window to open according to the Internet Explorer defaults. left: The left 

    (x-coordinate) position of the window,relative to the upper-left corner of the user's screen,

    in pixels. Must be a positive integer.location: Whether to display the Address bar,which 

    enables users to navigate the window to a new URL. Default is yes. menubar: Whether to display 

    menus on the new window. Default is yes.resizable: Whether the window can be resized by the 

    user. Default is yes.scrollbars: Whether the window has horizontal and vertical scroll bars. 

    Default is yes.status: Whether the window has a status bar at the bottom. Default is 

    yes.titlebar: Whether the title of the current page is displayed. Setting this option to no has 

    no effect within a managed application; the title bar will always appear.toolbar: Whether 

    toolbar buttons such as Back,Forward,and Stop are visible. Default is yes.top: The top 

    (y-coordinate) position of the window,relative to the upper-left corner of the user's screen,

    in pixels. Must be a positive integer.width: The width of the window's client area,in pixels. 

    The minimum is 100; attempts to open a window smaller than this will cause the window to open 

    according to the Internet Explorer defaults.

  

   replaceEntry: Whether url replaces the current window's URL in the navigation history. This will effect the 

    operation of methods on the System.Windows.Forms.HtmlHistory class.

  

   Returns: An System.Windows.Forms.HtmlWindow representing the new window,or the previously created window 

    named by the target parameter.
  """
  pass
 def OpenNew(self,*__args):
  """
  OpenNew(self: HtmlWindow,url: Uri,windowOptions: str) -> HtmlWindow

  

   Displays a file in a new window.

  

   url: The Uniform Resource Locator that describes the location of the file to load.

   windowOptions: A comma-delimited string consisting of zero or more of the following options in the form 

    name=value. See 

    System.Windows.Forms.HtmlWindow.Open(System.String,System.String,System.String,System.Boolean) 

    for a full description of the valid options.

  

   Returns: An System.Windows.Forms.HtmlWindow representing the new window.

  OpenNew(self: HtmlWindow,urlString: str,windowOptions: str) -> HtmlWindow

  

   Displays a file in a new window.

  

   urlString: The Uniform Resource Locator that describes the location of the file to load.

   windowOptions: A comma-delimited string consisting of zero or more of the following options in the form 

    name=value. See 

    System.Windows.Forms.HtmlWindow.Open(System.String,System.String,System.String,System.Boolean) 

    for a full description of the valid options.

  

   Returns: An System.Windows.Forms.HtmlWindow representing the new window.
  """
  pass
 def Prompt(self,message,defaultInputValue):
  """
  Prompt(self: HtmlWindow,message: str,defaultInputValue: str) -> str

  

   Shows a dialog box that displays a message and a text box to the user.

  

   message: The message to display to the user.

   defaultInputValue: The default value displayed in the text box.

   Returns: A System.String representing the text entered by the user.
  """
  pass
 def RemoveFocus(self):
  """
  RemoveFocus(self: HtmlWindow)

   Takes focus off of the current window.
  """
  pass
 def ResizeTo(self,*__args):
  """
  ResizeTo(self: HtmlWindow,size: Size)

   Changes the size of the window to the specified dimensions.

  

   size: A System.Drawing.Size describing the desired width and height of the window,in pixels. Must be 

    100 pixels or more in both dimensions.

  

  ResizeTo(self: HtmlWindow,width: int,height: int)

   Changes the size of the window to the specified dimensions.

  

   width: Describes the desired width of the window,in pixels. Must be 100 pixels or more.

   height: Describes the desired height of the window,in pixels. Must be 100 pixels or more.
  """
  pass
 def ScrollTo(self,*__args):
  """
  ScrollTo(self: HtmlWindow,point: Point)

   Moves the window to the specified coordinates.

  

   point: The x- and y-coordinates,relative to the top-left corner of the current window,toward which 

    the page should scroll.

  

  ScrollTo(self: HtmlWindow,x: int,y: int)

   Scrolls the window to the designated position.

  

   x: The x-coordinate,relative to the top-left corner of the current window,toward which the page 

    should scroll.

  

   y: The y-coordinate,relative to the top-left corner of the current window,toward which the page 

    should scroll.
  """
  pass
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==y """
  pass
 def __ne__(self,*args):
  pass
 Document=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the HTML document contained within the window.



Get: Document(self: HtmlWindow) -> HtmlDocument



"""

 DomWindow=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the unmanaged interface wrapped by this class.



Get: DomWindow(self: HtmlWindow) -> object



"""

 Frames=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a reference to each of the FRAME elements defined within the Web page.



Get: Frames(self: HtmlWindow) -> HtmlWindowCollection



"""

 History=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets an object containing the user's most recently visited URLs.



Get: History(self: HtmlWindow) -> HtmlHistory



"""

 IsClosed=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a value indicating whether this window is open or closed.



Get: IsClosed(self: HtmlWindow) -> bool



"""

 Name=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the name of the window.



Get: Name(self: HtmlWindow) -> str



Set: Name(self: HtmlWindow)=value

"""

 Opener=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a reference to the window that opened the current window.



Get: Opener(self: HtmlWindow) -> HtmlWindow



"""

 Parent=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the window which resides above the current one in a page containing frames.



Get: Parent(self: HtmlWindow) -> HtmlWindow



"""

 Position=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the position of the window's client area on the screen.



Get: Position(self: HtmlWindow) -> Point



"""

 Size=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the size of the current window.



Get: Size(self: HtmlWindow) -> Size



Set: Size(self: HtmlWindow)=value

"""

 StatusBarText=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the text displayed in the status bar of a window.



Get: StatusBarText(self: HtmlWindow) -> str



Set: StatusBarText(self: HtmlWindow)=value

"""

 Url=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the URL corresponding to the current item displayed in the window.



Get: Url(self: HtmlWindow) -> Uri



"""

 WindowFrameElement=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the frame element corresponding to this window.



Get: WindowFrameElement(self: HtmlWindow) -> HtmlElement



"""


 Error=None
 GotFocus=None
 Load=None
 LostFocus=None
 Resize=None
 Scroll=None
 Unload=None

